@@ -1,20 +1,21 @@
-/* common-pict.c
- * Copyright (C) 2009 Vivien Malerba <malerba@gnome-db.org>
+/*
+ * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <libgda/gda-value.h>
@@ -288,9 +289,8 @@ common_bin_adjust_menu (BinMenu *binmenu, gboolean editable, const GValue *value
 					g_free (size);
 #ifdef HAVE_GIO
 					GdaBlob *blob2;
-					glong read;
 					blob2 = (GdaBlob*) gda_blob_copy ((gpointer) blob);
-					read = gda_blob_op_read (blob2->op, blob2, 0, 1024);
+					gda_blob_op_read (blob2->op, blob2, 0, 1024);
 					bin = (GdaBinary *) blob2;
 					ctype = g_content_type_guess (NULL, bin->data,
 								      (gsize) bin->binary_length, NULL);
