@@ -39,15 +39,14 @@ static void gdaui_data_cell_renderer_boolean_class_init (GdauiDataCellRendererBo
 static void gdaui_data_cell_renderer_boolean_dispose    (GObject *object);
 static void gdaui_data_cell_renderer_boolean_finalize   (GObject *object);
 static void gdaui_data_cell_renderer_boolean_render     (GtkCellRenderer            *cell,
-							 GdkWindow                  *window,
+							 cairo_t                    *cr,
 							 GtkWidget                  *widget,
-							 GdkRectangle               *background_area,
-							 GdkRectangle               *cell_area,
-							 GdkRectangle               *expose_area,
+							 const GdkRectangle         *background_area,
+							 const GdkRectangle         *cell_area,
 							 GtkCellRendererState        flags);
 static void gdaui_data_cell_renderer_boolean_get_size   (GtkCellRenderer            *cell,
 							 GtkWidget                  *widget,
-							 GdkRectangle               *cell_area,
+							 const GdkRectangle         *cell_area,
 							 gint                       *x_offset,
 							 gint                       *y_offset,
 							 gint                       *width,
@@ -56,8 +55,8 @@ static gboolean gdaui_data_cell_renderer_boolean_activate  (GtkCellRenderer
 							    GdkEvent                   *event,
 							    GtkWidget                  *widget,
 							    const gchar                *path,
-							    GdkRectangle               *background_area,
-							    GdkRectangle               *cell_area,
+							    const GdkRectangle         *background_area,
+							    const GdkRectangle         *cell_area,
 							    GtkCellRendererState        flags);
 
 enum {
@@ -352,7 +351,7 @@ gdaui_data_cell_renderer_boolean_new (GdaDataHandler *dh, GType type)
 static void
 gdaui_data_cell_renderer_boolean_get_size (GtkCellRenderer *cell,
 					   GtkWidget       *widget,
-					   GdkRectangle    *cell_area,
+					   const GdkRectangle *cell_area,
 					   gint            *x_offset,
 					   gint            *y_offset,
 					   gint            *width,
@@ -365,17 +364,16 @@ gdaui_data_cell_renderer_boolean_get_size (GtkCellRenderer *cell,
 
 static void
 gdaui_data_cell_renderer_boolean_render (GtkCellRenderer      *cell,
-					 GdkWindow            *window,
+					 cairo_t              *cr,
 					 GtkWidget            *widget,
-					 GdkRectangle         *background_area,
-					 GdkRectangle         *cell_area,
-					 GdkRectangle         *expose_area,
+					 const GdkRectangle   *background_area,
+					 const GdkRectangle   *cell_area,
 					 GtkCellRendererState  flags)
 {
 	GdauiDataCellRendererBoolean *datacell = GDAUI_DATA_CELL_RENDERER_BOOLEAN (cell);
 	GtkCellRendererClass *toggle_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_TOGGLE);
 
-	(toggle_class->render) (cell, window, widget, background_area, cell_area, expose_area, flags);
+	(toggle_class->render) (cell, cr, widget, background_area, cell_area, flags);
 
 	if (datacell->priv->to_be_deleted) {
 		GtkStyle *style;
@@ -383,8 +381,7 @@ gdaui_data_cell_renderer_boolean_render (GtkCellRenderer      *cell,
 
 		g_object_get (G_OBJECT(widget), "style", &style, "xpad", &xpad, NULL);
 		gtk_paint_hline (style,
-				 window, GTK_STATE_SELECTED,
-				 cell_area,
+				 cr, GTK_STATE_SELECTED,
 				 widget,
 				 "hline",
 				 cell_area->x + xpad, cell_area->x + cell_area->width - xpad,
@@ -392,7 +389,7 @@ gdaui_data_cell_renderer_boolean_render (GtkCellRenderer      *cell,
 
 	}
 	if (datacell->priv->invalid)
-		gdaui_data_cell_renderer_draw_invalid_area (window, cell_area);
+		gdaui_data_cell_renderer_draw_invalid_area (cr, cell_area);
 }
 
 static gboolean
@@ -400,8 +397,8 @@ gdaui_data_cell_renderer_boolean_activate  (GtkCellRenderer            *cell,
 					    GdkEvent                   *event,
 					    GtkWidget                  *widget,
 					    const gchar                *path,
-					    GdkRectangle               *background_area,
-					    GdkRectangle               *cell_area,
+					    const GdkRectangle         *background_area,
+					    const GdkRectangle         *cell_area,
 					    GtkCellRendererState        flags)
 {
 	gboolean editable;
