@@ -1,22 +1,21 @@
-/* gdaui-data-cell-renderer-textual.c
- *
- * Copyright (C) 2000  Red Hat, Inc.,  Jonathan Blandford <jrb@redhat.com>
- * Copyright (C) 2003 - 2010 Vivien Malerba <malerba@gnome-db.org>
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #define OPTIMIZE 0
@@ -37,7 +36,7 @@
 #include "marshallers/gdaui-custom-marshal.h"
 #include "gdaui-data-cell-renderer-util.h"
 
-#define MAX_ACCEPTED_STRING_LENGTH 32500U
+#define MAX_ACCEPTED_STRING_LENGTH 800U
 
 static void gdaui_data_cell_renderer_textual_init       (GdauiDataCellRendererTextual      *celltext);
 static void gdaui_data_cell_renderer_textual_class_init (GdauiDataCellRendererTextualClass *class);
@@ -54,25 +53,24 @@ static void gdaui_data_cell_renderer_textual_set_property  (GObject *object,
 							    GParamSpec *pspec);
 static void gdaui_data_cell_renderer_textual_get_size   (GtkCellRenderer          *cell,
 							 GtkWidget                *widget,
-							 GdkRectangle             *cell_area,
+							 const GdkRectangle       *cell_area,
 							 gint                     *x_offset,
 							 gint                     *y_offset,
 							 gint                     *width,
 							 gint                     *height);
 static void gdaui_data_cell_renderer_textual_render     (GtkCellRenderer          *cell,
-							 GdkWindow                *window,
+							 cairo_t                  *cr,
 							 GtkWidget                *widget,
-							 GdkRectangle             *background_area,
-							 GdkRectangle             *cell_area,
-							 GdkRectangle             *expose_area,
+							 const GdkRectangle       *background_area,
+							 const GdkRectangle       *cell_area,
 							 GtkCellRendererState      flags);
 
 static GtkCellEditable *gdaui_data_cell_renderer_textual_start_editing (GtkCellRenderer      *cell,
 									GdkEvent             *event,
 									GtkWidget            *widget,
 									const gchar          *path,
-									GdkRectangle         *background_area,
-									GdkRectangle         *cell_area,
+									const GdkRectangle   *background_area,
+									const GdkRectangle   *cell_area,
 									GtkCellRendererState  flags);
 
 enum {
@@ -153,7 +151,7 @@ gdaui_data_cell_renderer_textual_init (GdauiDataCellRendererTextual *datacell)
 {
 	datacell->priv = g_new0 (GdauiDataCellRendererTextualPrivate, 1);
 	datacell->priv->dh = NULL;
-	datacell->priv->type = G_TYPE_INVALID;
+	datacell->priv->type = GDA_TYPE_NULL;
 	datacell->priv->type_forced = FALSE;
 	datacell->priv->value = NULL;
 	datacell->priv->options = NULL;
@@ -431,7 +429,7 @@ gdaui_data_cell_renderer_textual_set_property (GObject *object,
 				if (G_VALUE_TYPE (gval) != datacell->priv->type) {
 					if (!datacell->priv->type_forced) {
 						datacell->priv->type_forced = TRUE;
-						if (datacell->priv->type != G_TYPE_INVALID)
+						if (datacell->priv->type != GDA_TYPE_NULL)
 							g_warning (_("Data cell renderer's specified type (%s) "
 								     "differs from actual "
 								     "value to display type (%s)"),
@@ -453,21 +451,24 @@ gdaui_data_cell_renderer_textual_set_property (GObject *object,
 				if (! OPTIMIZE)
 					datacell->priv->value = gda_value_copy (gval);
 
-				if (!datacell->priv->dh && (datacell->priv->type != G_TYPE_INVALID))
-					datacell->priv->dh = g_object_ref (gda_get_default_handler (datacell->priv->type));
+				if (!datacell->priv->dh && (datacell->priv->type != GDA_TYPE_NULL))
+					datacell->priv->dh = g_object_ref (gda_data_handler_get_default (datacell->priv->type));
 
 				if (datacell->priv->dh) {
 					str = gda_data_handler_get_str_from_value (datacell->priv->dh, gval);
 					gboolean use_markup = FALSE;
 					if (str) {
 						gint length;
-						length = strlen (str);
+						length = g_utf8_strlen (str, -1);
 						if (length > MAX_ACCEPTED_STRING_LENGTH + too_long_msg_len) {
 							gchar *tmp;
-							tmp = g_markup_escape_text (str, MAX_ACCEPTED_STRING_LENGTH +
-										    too_long_msg_len);
+							tmp = g_utf8_offset_to_pointer (str,
+											MAX_ACCEPTED_STRING_LENGTH);
+							*tmp = 0;
+							tmp = g_markup_escape_text (str, -1);
 							g_free (str);
 							str = g_strconcat (tmp, too_long_msg, NULL);
+							g_free (tmp);
 							use_markup = TRUE;
 						}
 					}
@@ -582,7 +583,7 @@ gdaui_data_cell_renderer_textual_set_property (GObject *object,
  * value in the model, thus rendering a different string in each row
  * of the #GtkTreeView
  *
- * Return value: (transfer full): the new cell renderer
+ * Returns: (transfer full): the new cell renderer
  **/
 GtkCellRenderer *
 gdaui_data_cell_renderer_textual_new (GdaDataHandler *dh, GType type, const gchar *options)
@@ -601,7 +602,7 @@ gdaui_data_cell_renderer_textual_new (GdaDataHandler *dh, GType type, const gcha
 static void
 gdaui_data_cell_renderer_textual_get_size (GtkCellRenderer *cell,
 					   GtkWidget       *widget,
-					   GdkRectangle    *cell_area,
+					   const GdkRectangle *cell_area,
 					   gint            *x_offset,
 					   gint            *y_offset,
 					   gint            *width,
@@ -613,17 +614,16 @@ gdaui_data_cell_renderer_textual_get_size (GtkCellRenderer *cell,
 
 static void
 gdaui_data_cell_renderer_textual_render (GtkCellRenderer      *cell,
-					 GdkWindow            *window,
+					 cairo_t              *cr,
 					 GtkWidget            *widget,
-					 GdkRectangle         *background_area,
-					 GdkRectangle         *cell_area,
-					 GdkRectangle         *expose_area,
+					 const GdkRectangle   *background_area,
+					 const GdkRectangle   *cell_area,
 					 GtkCellRendererState  flags)
 
 {
 	GdauiDataCellRendererTextual *datacell = (GdauiDataCellRendererTextual*) cell;
 	GtkCellRendererClass *text_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_TEXT);
-	(text_class->render) (cell, window, widget, background_area, cell_area, expose_area, flags);
+	(text_class->render) (cell, cr, widget, background_area, cell_area, flags);
 
 	if (datacell->priv->to_be_deleted) {
 		GtkStyle *style;
@@ -633,8 +633,7 @@ gdaui_data_cell_renderer_textual_render (GtkCellRenderer      *cell,
 		g_object_get ((GObject*) cell, "xpad", &xpad, NULL);
 
 		gtk_paint_hline (style,
-				 window, GTK_STATE_SELECTED,
-				 cell_area,
+				 cr, GTK_STATE_SELECTED,
 				 widget,
 				 "hline",
 				 cell_area->x + xpad, cell_area->x + cell_area->width - xpad,
@@ -642,7 +641,7 @@ gdaui_data_cell_renderer_textual_render (GtkCellRenderer      *cell,
 		g_object_unref (style);
 	}
 	if (datacell->priv->invalid)
-		gdaui_data_cell_renderer_draw_invalid_area (window, cell_area);
+		gdaui_data_cell_renderer_draw_invalid_area (cr, cell_area);
 }
 
 static void
@@ -692,8 +691,8 @@ gdaui_data_cell_renderer_textual_start_editing (GtkCellRenderer      *cell,
 						G_GNUC_UNUSED GdkEvent             *event,
 						G_GNUC_UNUSED GtkWidget            *widget,
 						const gchar          *path,
-						G_GNUC_UNUSED GdkRectangle         *background_area,
-						G_GNUC_UNUSED GdkRectangle         *cell_area,
+						G_GNUC_UNUSED const GdkRectangle *background_area,
+						G_GNUC_UNUSED const GdkRectangle *cell_area,
 						G_GNUC_UNUSED GtkCellRendererState  flags)
 {
 	GdauiDataCellRendererTextual *datacell;
