@@ -1,21 +1,21 @@
-/* gdaui-entry-shell.c
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * Copyright (C) 2003 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <gdk/gdkkeysyms.h>
@@ -56,7 +56,6 @@ struct  _GdauiEntryShellPriv {
         GtkWidget           *embedder;
 	GtkWidget           *hbox;
         GtkWidget           *button;
-        GtkStyle            *orig_style;
         GdaDataHandler      *data_handler;
 	gboolean             show_actions;
 
@@ -159,7 +158,6 @@ gdaui_entry_shell_init (GdauiEntryShell * shell)
 	/* Setting the initial layout */
 	gtk_viewport_set_shadow_type (GTK_VIEWPORT (shell), GTK_SHADOW_NONE);
 	gtk_container_set_border_width (GTK_CONTAINER (shell), 0);
-	shell->priv->orig_style = gtk_style_copy (gtk_widget_get_style (GTK_WIDGET (shell)));
 
 	/* hbox */
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -382,16 +380,14 @@ gdaui_entry_shell_refresh_status_display (GdauiEntryShell *shell)
 {
 	static GdkColor **colors = NULL;
 	GdkColor *normal = NULL, *prelight = NULL;
-	GdkColor *orig_normal, *orig_prelight;
 
 	g_return_if_fail (GDAUI_IS_ENTRY_SHELL (shell));
 
-	orig_normal = & (shell->priv->orig_style->bg[GTK_STATE_NORMAL]);
-	orig_prelight = & (shell->priv->orig_style->bg[GTK_STATE_PRELIGHT]);
-
 	if (!colors)
 		colors = _gdaui_utility_entry_build_info_colors_array ();
 
+	gtk_widget_set_tooltip_text (shell->priv->button, NULL);
+
 	if (shell->priv->value_is_null) {
 		normal = colors[0];
 		prelight = colors[1];
@@ -410,11 +406,6 @@ gdaui_entry_shell_refresh_status_display (GdauiEntryShell *shell)
 		gtk_widget_set_tooltip_text (shell->priv->button, _("Value is invalid"));
 	}
 
-	if (!normal)
-		normal = orig_normal;
-	if (!prelight)
-		prelight = orig_prelight;
-
 	gtk_widget_modify_bg (shell->priv->button, GTK_STATE_NORMAL, normal);
 	gtk_widget_modify_bg (shell->priv->button, GTK_STATE_ACTIVE, normal);
 	gtk_widget_modify_bg (shell->priv->button, GTK_STATE_PRELIGHT, prelight);
