@@ -1,26 +1,27 @@
-/* common-pict.c
- * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include "common-pict.h"
 #include <string.h>
 #include <libgda/gda-quark-list.h>
 #include <libgda/gda-blob-op.h>
+#include <libgda-ui/libgda-ui.h>
 
 /*
  * Fills in @bindata->data and @bindata->data_length with the contents of @value.
@@ -282,6 +283,17 @@ typedef struct {
 } PictMenuData;
 static void file_load_cb (GtkWidget *button, PictMenuData *menudata);
 static void file_save_cb (GtkWidget *button, PictMenuData *menudata);
+static void copy_cb (GtkWidget *button, PictMenuData *menudata);
+
+static void
+menudata_free (PictMenuData *menudata)
+{
+	if (menudata->bindata) {
+		g_free (menudata->bindata->data);
+		g_free (menudata->bindata);
+	}
+	g_free (menudata);
+}
 
 void
 common_pict_create_menu (PictMenu *pictmenu, GtkWidget *attach_to, PictBinData *bindata, PictOptions *options,
@@ -291,7 +303,9 @@ common_pict_create_menu (PictMenu *pictmenu, GtkWidget *attach_to, PictBinData *
 	PictMenuData *menudata;
 	
 	menudata = g_new (PictMenuData, 1);
-	menudata->bindata = bindata;
+	menudata->bindata = g_new (PictBinData, 1);
+	menudata->bindata->data = g_memdup (bindata->data, bindata->data_length);
+	menudata->bindata->data_length = bindata->data_length;
 	menudata->options = options;
 	menudata->callback = callback;
 	menudata->data = data;
@@ -301,7 +315,15 @@ common_pict_create_menu (PictMenu *pictmenu, GtkWidget *attach_to, PictBinData *
 	g_signal_connect (menu, "deactivate", 
 			  G_CALLBACK (gtk_widget_hide), NULL);
 	pictmenu->menu = menu;
-		
+
+	mitem = gtk_menu_item_new_with_mnemonic (_("_Copy image"));
+	gtk_widget_show (mitem);
+	gtk_container_add (GTK_CONTAINER (menu), mitem);
+	g_signal_connect (mitem, "activate",
+			  G_CALLBACK (copy_cb), menudata);
+	gtk_widget_set_sensitive (mitem, bindata->data ? TRUE : FALSE);
+	pictmenu->copy_mitem = mitem;
+
 	mitem = gtk_menu_item_new_with_mnemonic (_("_Load image from file"));
 	gtk_widget_show (mitem);
 	gtk_container_add (GTK_CONTAINER (menu), mitem);
@@ -335,7 +357,9 @@ file_load_cb (GtkWidget *button, PictMenuData *menudata)
 	filter = gtk_file_filter_new ();
 	gtk_file_filter_add_pixbuf_formats (filter);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dlg), filter);
-	
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlg),
+					     gdaui_get_default_path ());	
+
 	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_ACCEPT) {
 		char *filename;
 		gsize length;
@@ -343,6 +367,7 @@ file_load_cb (GtkWidget *button, PictMenuData *menudata)
 		gchar *data;
 
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dlg));
+		gdaui_set_default_path (gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dlg)));
 
 		if (g_file_get_contents (filename, &data, &length, &error)) {
 			if (menudata->bindata->data) {
@@ -454,8 +479,10 @@ file_save_cb (GtkWidget *button, PictMenuData *menudata)
 					   GTK_WINDOW (gtk_widget_get_toplevel (button)),
 					   GTK_FILE_CHOOSER_ACTION_SAVE, 
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					   GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 					   NULL);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlg),
+					     gdaui_get_default_path ());
 
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dlg), expander);
 	if (gtk_dialog_run (GTK_DIALOG (dlg)) == GTK_RESPONSE_ACCEPT) {
@@ -466,6 +493,7 @@ file_save_cb (GtkWidget *button, PictMenuData *menudata)
 
 		format = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dlg));
+		gdaui_set_default_path (gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dlg)));
 
 		if (format == 0) {
 			/* save data AS IS */
@@ -515,6 +543,38 @@ file_save_cb (GtkWidget *button, PictMenuData *menudata)
 	g_slist_free (pictformat.formats);
 }
 
+static void
+copy_cb (GtkWidget *button, PictMenuData *menudata)
+{
+	GtkClipboard *cp;
+	cp = gtk_clipboard_get (gdk_atom_intern_static_string ("CLIPBOARD"));
+	if (!cp)
+		return;
+
+	GdkPixbufLoader *loader;
+	GdkPixbuf *pixbuf = NULL;
+	loader = gdk_pixbuf_loader_new ();
+	if (gdk_pixbuf_loader_write (loader, menudata->bindata->data,
+				     menudata->bindata->data_length, NULL)) {
+		if (gdk_pixbuf_loader_close (loader, NULL)) {
+			pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
+			g_object_ref (pixbuf);
+		}
+		else
+			gdk_pixbuf_loader_close (loader, NULL);
+	}
+	else
+		gdk_pixbuf_loader_close (loader, NULL);
+	g_object_unref (loader);
+	
+	if (pixbuf) {
+		gtk_clipboard_set_image (cp, pixbuf);
+		g_object_unref (pixbuf);
+	}
+	else
+		gtk_clipboard_set_image (cp, NULL);
+}
+
 /* 
  * adjust the sensitiveness of the menu items in the popup menu
  */
@@ -525,6 +585,7 @@ common_pict_adjust_menu_sensitiveness (PictMenu *pictmenu, gboolean editable, Pi
 		return;
 	gtk_widget_set_sensitive (pictmenu->load_mitem, editable);
 	gtk_widget_set_sensitive (pictmenu->save_mitem, bindata->data ? TRUE : FALSE);
+	gtk_widget_set_sensitive (pictmenu->copy_mitem, bindata->data ? TRUE : FALSE);
 }
 
 /*
