@@ -1,21 +1,21 @@
-/* gdaui-entry-pict.c
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * Copyright (C) 2006 - 2011 Vivien Malerba
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -144,7 +144,6 @@ gdaui_entry_pict_new (GdaDataHandler *dh, GType type, const gchar *options)
 	GdauiEntryPict *mgpict;
 
 	g_return_val_if_fail (GDA_IS_DATA_HANDLER (dh), NULL);
-	g_return_val_if_fail (type != G_TYPE_INVALID, NULL);
 	g_return_val_if_fail (gda_data_handler_accepts_g_type (dh, type), NULL);
 
 	obj = g_object_new (GDAUI_TYPE_ENTRY_PICT, "handler", dh, NULL);
@@ -289,10 +288,13 @@ do_popup_menu (GtkWidget *widget, GdkEventButton *event, GdauiEntryPict *mgpict)
 {
 	int button, event_time;
 	
-	if (!mgpict->priv->popup_menu.menu)
-		common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
-					 &(mgpict->priv->options), 
-					 (PictCallback) pict_data_changed_cb, mgpict);
+	if (mgpict->priv->popup_menu.menu) {
+		gtk_widget_destroy (mgpict->priv->popup_menu.menu);
+		mgpict->priv->popup_menu.menu = NULL;
+	}
+	common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
+				 &(mgpict->priv->options), 
+				 (PictCallback) pict_data_changed_cb, mgpict);
 
 	common_pict_adjust_menu_sensitiveness (&(mgpict->priv->popup_menu), mgpict->priv->editable, 
 						       &(mgpict->priv->bindata));
@@ -325,11 +327,14 @@ event_cb (GtkWidget *widget, GdkEvent *event, GdauiEntryPict *mgpict)
 	}
 	if ((event->type == GDK_2BUTTON_PRESS) && (((GdkEventButton *) event)->button == 1)) {
 		if (mgpict->priv->editable) {
-			if (!mgpict->priv->popup_menu.menu) 
-				common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
-							 &(mgpict->priv->options), 
-							 (PictCallback) pict_data_changed_cb, mgpict);
-
+			if (mgpict->priv->popup_menu.menu) {
+				gtk_widget_destroy (mgpict->priv->popup_menu.menu);
+				mgpict->priv->popup_menu.menu = NULL;
+			}
+			common_pict_create_menu (&(mgpict->priv->popup_menu), widget, &(mgpict->priv->bindata), 
+						 &(mgpict->priv->options), 
+						 (PictCallback) pict_data_changed_cb, mgpict);
+			
 			common_pict_adjust_menu_sensitiveness (&(mgpict->priv->popup_menu), mgpict->priv->editable, 
 							       &(mgpict->priv->bindata));
 			
