@@ -33,12 +33,8 @@ do_form_rw (GtkWidget *do_widget)
 				  G_CALLBACK (gtk_widget_destroyed), &window);
 		
 		vbox = gtk_vbox_new (FALSE, 5);
-#if GTK_CHECK_VERSION(2,18,0)
 		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (window))),
 				    vbox, TRUE, TRUE, 0);
-#else
-		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), vbox, TRUE, TRUE, 0);
-#endif
 		gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 		
 		label = gtk_label_new ("The following GdauiForm widget displays data from the 'products' table.\n\n"
