@@ -1,24 +1,21 @@
 /*
- * Copyright (C) 1999 - 2011 The GNOME Foundation.
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- * 	Rodrigo Moya <rodrigo@gnome-db.org>
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -115,7 +112,7 @@ gdaui_new_data_entry (GType type, const gchar *plugin_name)
 	if (!gdaui_plugins_hash)
 		gdaui_plugins_hash = init_plugins_hash ();
 
-	if (type == G_TYPE_INVALID)
+	if (type == GDA_TYPE_NULL)
 		return (GdauiDataEntry *) gdaui_entry_none_new (GDA_TYPE_NULL);
 
 	dh = gda_data_handler_get_default (type);
@@ -734,3 +731,40 @@ get_spec_with_isocodes (const gchar *file)
 
 	return retval;
 }
+
+static gchar *gdaui_path = NULL;
+
+/**
+ * gdaui_get_default_path:
+ *
+ * Get the default path used when saving a file, or when showing a #GtkFileChooser file chooser.
+ * When the application starts, the default path will be the same as the onde returned by
+ * g_get_current_dir().
+ *
+ * Returns: (transfer none): the default path, or %NULL
+ *
+ * Since: 4.2.9
+ */
+const gchar *
+gdaui_get_default_path (void)
+{
+	if (! gdaui_path)
+		gdaui_path = g_get_current_dir ();
+	return gdaui_path;
+}
+
+/**
+ * gdaui_set_default_path:
+ *
+ * Define the default path used when saving a file, or when showing a #GtkFileChooser file chooser.
+ *
+ * Since: 4.2.9
+ */
+void
+gdaui_set_default_path (const gchar *path)
+{
+	g_free (gdaui_path);
+	gdaui_path = NULL;
+	if (path)
+		gdaui_path = g_strdup (path);
+}
