@@ -1,25 +1,37 @@
-/* 
- * Copyright (C) 1998 - 2011 The GNOME Foundation.
+/*
+ * Copyright (C) 2001 - 2004 Rodrigo Moya <rodrigo@gnome-db.org>
+ * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
+ * Copyright (C) 2002 Holger Thon <holger.thon@gnome-db.org>
+ * Copyright (C) 2003 Laurent Sansonetti <lrz@src.gnome.org>
+ * Copyright (C) 2003 Paisa Seeluangsawat <paisa@users.sf.net>
+ * Copyright (C) 2003 Philippe CHARLIER <p.charlier@chello.be>
+ * Copyright (C) 2004 Dani Baeyens <daniel.baeyens@hispalinux.es>
+ * Copyright (C) 2004 Szalai Ferenc <szferi@einstein.ki.iif.hu>
+ * Copyright (C) 2004 - 2005 lvaro Pea <alvaropg@telefonica.net>
+ * Copyright (C) 2005 - 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2005 Dan Winship <danw@src.gnome.org>
+ * Copyright (C) 2005 Stanislav Brabec <sbrabec@suse.de>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2007 Leonardo Boshell <lb@kmc.com.co>
+ * Copyright (C) 2008 Phil Longstaff <plongstaff@rogers.com>
+ * Copyright (C) 2008 Przemysław Grzegorczyk <pgrzegorczyk@gmail.com>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *	Rodrigo Moya <rodrigo@gnome-db.org>
- *	Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -244,7 +256,7 @@ gda_data_model_row_inserted (GdaDataModel *model, gint row)
 		for (i = 0; i < nbcols; i++) {
 			column = gda_data_model_describe_column (model, i);
 			value = gda_data_model_get_value_at (model, i, 0, NULL);
-			if (value && (gda_column_get_g_type (column) == G_TYPE_INVALID))
+			if (value && (gda_column_get_g_type (column) == GDA_TYPE_NULL))
 				gda_column_set_g_type (column, G_VALUE_TYPE ((GValue *)value));
 		}
 	}
@@ -1610,8 +1622,7 @@ add_xml_row (GdaDataModel *model, xmlNodePtr xml_row, GError **error)
 		}
 
 		gdatype = gda_column_get_g_type (column);
-		if ((gdatype == G_TYPE_INVALID) ||
-		    (gdatype == GDA_TYPE_NULL)) {
+		if ((gdatype == G_TYPE_INVALID) || (gdatype == GDA_TYPE_NULL)) {
 			g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_XML_FORMAT_ERROR,
 				      "%s", _("Cannot retrieve column data type (type is UNKNOWN or not specified)"));
 			retval = FALSE;
@@ -1630,14 +1641,12 @@ add_xml_row (GdaDataModel *model, xmlNodePtr xml_row, GError **error)
 			value = g_new0 (GValue, 1);
 			gchar* nodeval = (gchar*)xmlNodeGetContent (xml_field);
 			if (nodeval) {
-				if (!gda_value_set_from_string (value, nodeval, gdatype)) {
-					g_free (value);
-					value = gda_value_new_null ();
-				}
+				if (!gda_value_set_from_string (value, nodeval, gdatype))
+					gda_value_set_null (value);
 				xmlFree(nodeval);
 			}
 			else
-				value = gda_value_new_null ();	
+				gda_value_set_null (value);
 		}
 
 		g_ptr_array_index (values, pos) = value;
@@ -1847,9 +1856,8 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 
 		column = gda_data_model_describe_column (to, i);
 		if (plist->data) {
-			if ((gda_holder_get_g_type (GDA_HOLDER (plist->data)) != 
-			     gda_column_get_g_type (column)) &&
-			    (gda_column_get_g_type (column) != G_TYPE_INVALID)) {
+			if ((gda_holder_get_g_type (GDA_HOLDER (plist->data)) != gda_column_get_g_type (column)) &&
+			    (gda_column_get_g_type (column) != GDA_TYPE_NULL)) {
 				GValue *newval;
 				
 				newval = g_new0 (GValue, 1);
@@ -1902,7 +1910,7 @@ gda_data_model_import_from_model (GdaDataModel *to, GdaDataModel *from,
 				value = (GValue *) gda_holder_get_value (GDA_HOLDER (plist->data));
 				if (avlist->data) {
 					if (append_types [i] && gda_value_is_null ((GValue *) (avlist->data))) 
-						g_value_init ((GValue *) (avlist->data), append_types [i]);
+						gda_value_reset_with_type ((GValue *) (avlist->data), append_types [i]);
 					if (!gda_value_is_null (value) && 
 					    !g_value_transform (value, (GValue *) (avlist->data))) {
 						gchar *str;
@@ -2232,9 +2240,8 @@ real_gda_data_model_dump_as_string (GdaDataModel *model, gboolean dump_attribute
 
 #ifdef HAVE_LOCALE_H
 #ifndef G_OS_WIN32
-	char *current_locale;
 	int utf8_mode;
-	current_locale = setlocale (LC_ALL, NULL);
+	setlocale (LC_ALL, NULL);
 	utf8_mode = (strcmp (nl_langinfo (CODESET), "UTF-8") == 0);
 	if (utf8_mode) {
 		sep_col = " │ ";
