@@ -1,24 +1,26 @@
 /*
- * Copyright (C) 1998 - 2011 The GNOME Foundation.
+ * Copyright (C) 2001 - 2004 Rodrigo Moya <rodrigo@gnome-db.org>
+ * Copyright (C) 2002 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
+ * Copyright (C) 2003 Laurent Sansonetti <lrz@gnome.org>
+ * Copyright (C) 2005 Dan Winship <danw@src.gnome.org>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
+ * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
  *
- * AUTHORS:
- *	Rodrigo Moya <rodrigo@gnome-db.org>
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #ifndef __GDA_DATA_MODEL_H__
