@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2008 Massimo Cora <maxcvs@email.it>
- * Copyright (C) 2008 Murray Cumming <murrayc@src.gnome.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
@@ -36,8 +36,6 @@
 #include <libgda/gda-custom-marshal.h>
 #include <libgda/gda-types.h>
 
-#define __gda_value_is_null(value) (!G_IS_VALUE (value))
-
 /* 
  * Main static functions 
  */
@@ -55,15 +53,7 @@ static void gda_holder_get_property (GObject *object,
 				     GValue *value,
 				     GParamSpec *pspec);
 
-/* GdaLockable interface */
-static void                 gda_holder_lockable_init (GdaLockableIface *iface);
-static void                 gda_holder_lock      (GdaLockable *lockable);
-static gboolean             gda_holder_trylock   (GdaLockable *lockable);
-static void                 gda_holder_unlock    (GdaLockable *lockable);
-
-
-static void bound_holder_changed_cb (GdaHolder *alias_of, GdaHolder *holder);
-static void full_bound_holder_changed_cb (GdaHolder *alias_of, GdaHolder *holder);
+static void full_bind_changed_cb (GdaHolder *alias_of, GdaHolder *holder);
 static void gda_holder_set_full_bind (GdaHolder *holder, GdaHolder *alias_of);
 
 /* get a pointer to the parents to be able to call their destructor */
@@ -106,10 +96,9 @@ struct _GdaHolderPrivate
 	GType            g_type;
 	GdaHolder       *full_bind;     /* FULL bind to holder */
 	GdaHolder       *simple_bind;  /* SIMPLE bind to holder */
-	gulong           simple_bind_type_changed_id;
+	gulong           simple_bind_notify_signal_id;
 	
 	gboolean         invalid_forced;
-	GError          *invalid_error;
 	gboolean         valid;
 	gboolean         is_freeable;
 
@@ -120,8 +109,6 @@ struct _GdaHolderPrivate
 
 	GdaDataModel    *source_model;
 	gint             source_col;
-
-	GdaMutex        *mutex;
 };
 
 /* module error */
@@ -152,18 +139,10 @@ gda_holder_get_type (void)
 			(GInstanceInitFunc) gda_holder_init,
 			0
 		};
-
-		static GInterfaceInfo lockable_info = {
-                        (GInterfaceInitFunc) gda_holder_lockable_init,
-			NULL,
-                        NULL
-                };
 		
 		g_static_mutex_lock (&registering);
-		if (type == 0) {
+		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaHolder", &info, 0);
-			g_type_add_interface_static (type, GDA_TYPE_LOCKABLE, &lockable_info);
-		}
 		g_static_mutex_unlock (&registering);
 	}
 
@@ -264,7 +243,7 @@ gda_holder_class_init (GdaHolderClass *class)
                               G_SIGNAL_RUN_LAST,
                               G_STRUCT_OFFSET (GdaHolderClass, validate_change),
                               validate_change_accumulator, NULL,
-                              _gda_marshal_ERROR__VALUE, GDA_TYPE_ERROR, 1, G_TYPE_VALUE);
+                              _gda_marshal_ERROR__VALUE, G_TYPE_ERROR, 1, G_TYPE_VALUE);
 
         class->changed = NULL;
         class->source_changed = NULL;
@@ -319,14 +298,6 @@ gda_holder_class_init (GdaHolderClass *class)
 	gda_holder_attributes_manager = gda_attributes_manager_new (TRUE, holder_attribute_set_cb, NULL);
 }
 
-static void
-gda_holder_lockable_init (GdaLockableIface *iface)
-{
-	iface->i_lock = gda_holder_lock;
-	iface->i_trylock = gda_holder_trylock;
-	iface->i_unlock = gda_holder_unlock;
-}
-
 static void
 gda_holder_init (GdaHolder *holder)
 {
@@ -334,13 +305,12 @@ gda_holder_init (GdaHolder *holder)
 
 	holder->priv->id = NULL;
 
-	holder->priv->g_type = G_TYPE_INVALID;
+	holder->priv->g_type = GDA_TYPE_NULL;
 	holder->priv->full_bind = NULL;
 	holder->priv->simple_bind = NULL;
-	holder->priv->simple_bind_type_changed_id = 0;
+	holder->priv->simple_bind_notify_signal_id = 0;
 
 	holder->priv->invalid_forced = FALSE;
-	holder->priv->invalid_error = NULL;
 	holder->priv->valid = TRUE;
 	holder->priv->default_forced = FALSE;
 	holder->priv->is_freeable = TRUE;
@@ -350,8 +320,6 @@ gda_holder_init (GdaHolder *holder)
 	holder->priv->not_null = FALSE;
 	holder->priv->source_model = NULL;
 	holder->priv->source_col = 0;
-
-	holder->priv->mutex = gda_mutex_new ();
 }
 
 /**
@@ -389,7 +357,6 @@ gda_holder_copy (GdaHolder *orig)
 	g_return_val_if_fail (orig && GDA_IS_HOLDER (orig), NULL);
 	g_return_val_if_fail (orig->priv, NULL);
 
-	gda_holder_lock ((GdaLockable*) orig);
 	obj = g_object_new (GDA_TYPE_HOLDER, "g-type", orig->priv->g_type, NULL);
 	holder = GDA_HOLDER (obj);
 
@@ -410,8 +377,6 @@ gda_holder_copy (GdaHolder *orig)
 	if (allok) {
 		/* direct settings */
 		holder->priv->invalid_forced = orig->priv->invalid_forced;
-		if (orig->priv->invalid_error)
-			holder->priv->invalid_error = g_error_copy (orig->priv->invalid_error);
 		holder->priv->valid = orig->priv->valid;
 		holder->priv->is_freeable = TRUE;
 		holder->priv->default_forced = orig->priv->default_forced;	
@@ -428,13 +393,11 @@ gda_holder_copy (GdaHolder *orig)
 		gda_value_free (att_value);
 
 
-		gda_holder_unlock ((GdaLockable*) orig);
 		return holder;
 	}
 	else {
 		g_warning ("Internal error: could not copy GdaHolder (please report a bug).");
 		g_object_unref (holder);
-		gda_holder_unlock ((GdaLockable*) orig);
 		return NULL;
 	}
 }
@@ -442,7 +405,7 @@ gda_holder_copy (GdaHolder *orig)
 /**
  * gda_holder_new_inline: (skip)
  * @type: a valid GLib type
- * @id: (allow-none): the id of the holder to create, or %NULL
+ * @id: the id of the holder to create, or %NULL
  * @...: value to set
  *
  * Creates a new #GdaHolder object with an ID set to @id, of type @type, 
@@ -565,11 +528,6 @@ gda_holder_dispose (GObject *object)
 			gda_value_free (holder->priv->default_value);
 			holder->priv->default_value = NULL;
 		}
-
-		if (holder->priv->invalid_error) {
-			g_error_free (holder->priv->invalid_error);
-			holder->priv->invalid_error = NULL;
-		}
 	}
 
 	/* parent class */
@@ -588,8 +546,6 @@ gda_holder_finalize (GObject   * object)
 	if (holder->priv) {
 		g_free (holder->priv->id);
 
-		gda_mutex_free (holder->priv->mutex);
-
 		g_free (holder->priv);
 		holder->priv = NULL;
 	}
@@ -635,11 +591,11 @@ gda_holder_set_property (GObject *object,
 				
 				/* updating the holder's validity regarding the NULL value */
 				if (!not_null && 
-				    (!holder->priv->value || __gda_value_is_null (holder->priv->value)))
+				    (!holder->priv->value || GDA_VALUE_HOLDS_NULL (holder->priv->value)))
 					holder->priv->valid = TRUE;
 				
 				if (not_null && 
-				    (!holder->priv->value || __gda_value_is_null (holder->priv->value)))
+				    (!holder->priv->value || GDA_VALUE_HOLDS_NULL (holder->priv->value)))
 					holder->priv->valid = FALSE;
 				
 				g_signal_emit (holder, gda_holder_signals[CHANGED], 0);
@@ -647,11 +603,11 @@ gda_holder_set_property (GObject *object,
 			break;
 		}
 		case PROP_SIMPLE_BIND:
-			if (!gda_holder_set_bind (holder, (GdaHolder*) g_value_get_object (value), NULL))
+			if (!gda_holder_set_bind (holder, GDA_HOLDER (g_value_get_object (value)), NULL))
 				g_warning ("Could not set the 'simple-bind' property");
 			break;
 		case PROP_FULL_BIND:
-			gda_holder_set_full_bind (holder, (GdaHolder*) g_value_get_object (value));
+			gda_holder_set_full_bind (holder, GDA_HOLDER (g_value_get_object (value)));
 			break;
 		case PROP_SOURCE_MODEL: {
 			GdaDataModel* ptr = g_value_get_object (value);
@@ -705,13 +661,13 @@ gda_holder_get_property (GObject *object,
 			g_value_set_boolean (value, gda_holder_get_not_null (holder));
 			break;
 		case PROP_SIMPLE_BIND:
-			g_value_set_object (value, (GObject*) holder->priv->simple_bind);
+			g_value_set_object (value, G_OBJECT (holder->priv->simple_bind));
 			break;
 		case PROP_FULL_BIND:
-			g_value_set_object (value, (GObject*) holder->priv->full_bind);
+			g_value_set_object (value, G_OBJECT (holder->priv->full_bind));
 			break;
 		case PROP_SOURCE_MODEL:
-			g_value_set_object (value, (GObject*) holder->priv->source_model);
+			g_value_set_object (value, G_OBJECT (holder->priv->source_model));
 			break;
 		case PROP_SOURCE_COLUMN:
 			g_value_set_int (value, holder->priv->source_col);
@@ -817,20 +773,16 @@ gda_holder_get_value_str (GdaHolder *holder, GdaDataHandler *dh)
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), NULL);
 	g_return_val_if_fail (holder->priv, NULL);
 
-	gda_holder_lock ((GdaLockable*) holder);
 	current_val = gda_holder_get_value (holder);
-        if (!current_val || __gda_value_is_null (current_val)) {
-		gda_holder_unlock ((GdaLockable*) holder);
+        if (!current_val || GDA_VALUE_HOLDS_NULL (current_val))
                 return NULL;
-	}
         else {
-		gchar *retval = NULL;
                 if (!dh)
 			dh = gda_data_handler_get_default (holder->priv->g_type);
 		if (dh)
-                        retval = gda_data_handler_get_str_from_value (dh, current_val);
-		gda_holder_unlock ((GdaLockable*) holder);
-		return retval;
+                        return gda_data_handler_get_str_from_value (dh, current_val);
+                else
+                        return NULL;
         }
 }
 
@@ -897,24 +849,22 @@ gda_holder_set_value_str (GdaHolder *holder, GdaDataHandler *dh, const gchar *va
 
 	if (!value || !g_ascii_strcasecmp (value, "NULL")) 
                 return gda_holder_set_value (holder, NULL, error);
-    else {
+	else {
 		GValue *gdaval = NULL;
-		gboolean retval = FALSE;
-
-		gda_holder_lock ((GdaLockable*) holder);
+		
 		if (!dh)
 			dh = gda_data_handler_get_default (holder->priv->g_type);
 		if (dh)
 			gdaval = gda_data_handler_get_value_from_str (dh, value, holder->priv->g_type);
-
+		
 		if (gdaval)
-			retval = real_gda_holder_set_value (holder, gdaval, FALSE, error);
-		else
+			return real_gda_holder_set_value (holder, gdaval, FALSE, error);
+		else {
 			g_set_error (error, GDA_HOLDER_ERROR, GDA_HOLDER_STRING_CONVERSION_ERROR,
 				     _("Unable to convert string to '%s' type"), 
 				     gda_g_type_to_string (holder->priv->g_type));
-		gda_holder_unlock ((GdaLockable*) holder);
-		return retval;
+			return FALSE;
+		}
 	}
 }
 
@@ -962,28 +912,25 @@ real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, G
 	gboolean newvalid;
 	const GValue *current_val;
 	gboolean newnull;
-	gboolean was_valid;
 #define DEBUG_HOLDER
 #undef DEBUG_HOLDER
 
-	gda_holder_lock ((GdaLockable*) holder);
-	was_valid = gda_holder_is_valid (holder);
+	gboolean was_valid = gda_holder_is_valid (holder);
 
 	/* if the value has been set with gda_holder_take_static_value () you'll be able
 	 * to change the value only with another call to real_gda_holder_set_value 
 	 */
 	if (!holder->priv->is_freeable) {
-		gda_holder_unlock ((GdaLockable*) holder);
 		g_warning (_("Can't use this method to set value because there is already a static value"));
 		return FALSE;
 	}
 		
 	/* holder will be changed? */
-	newnull = !value || __gda_value_is_null (value);
+	newnull = !value || GDA_VALUE_HOLDS_NULL (value);
 	current_val = gda_holder_get_value (holder);
 	if (current_val == value)
 		changed = FALSE;
-	else if ((!current_val || __gda_value_is_null ((GValue *)current_val)) && newnull)
+	else if ((!current_val || GDA_VALUE_HOLDS_NULL ((GValue *)current_val)) && newnull)
 		changed = FALSE;
 	else if (value && current_val &&
 		 (G_VALUE_TYPE (value) == G_VALUE_TYPE ((GValue *)current_val)))
@@ -1026,12 +973,7 @@ real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, G
 		if (!do_copy && value)
 			gda_value_free (value);
 		holder->priv->invalid_forced = FALSE;
-		if (holder->priv->invalid_error) {
-			g_error_free (holder->priv->invalid_error);
-			holder->priv->invalid_error = NULL;
-		}
 		holder->priv->valid = newvalid;
-		gda_holder_unlock ((GdaLockable*) holder);
 		return TRUE;
 	}
 
@@ -1047,16 +989,11 @@ real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, G
 		g_propagate_error (error, lerror);
 		if (!do_copy) 
 			gda_value_free (value);
-		gda_holder_unlock ((GdaLockable*) holder);
 		return FALSE;
 	}
 
 	/* new valid status */
 	holder->priv->invalid_forced = FALSE;
-	if (holder->priv->invalid_error) {
-		g_error_free (holder->priv->invalid_error);
-		holder->priv->invalid_error = NULL;
-	}
 	holder->priv->valid = newvalid;
 	/* we're setting a non-static value, so be sure to flag is as freeable */
 	holder->priv->is_freeable = TRUE;
@@ -1081,7 +1018,6 @@ real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, G
 		g_print ("Holder %p is alias of holder %p => propagating changes to holder %p\n",
 			 holder, holder->priv->full_bind, holder->priv->full_bind);
 #endif
-		gda_holder_unlock ((GdaLockable*) holder);
 		return real_gda_holder_set_value (holder->priv->full_bind, value, do_copy, error);
 	}
 	else {
@@ -1104,7 +1040,6 @@ real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, G
 		g_signal_emit (holder, gda_holder_signals[CHANGED], 0);
 	}
 
-	gda_holder_unlock ((GdaLockable*) holder);
 	return newvalid;
 }
 
@@ -1125,11 +1060,11 @@ real_gda_holder_set_const_value (GdaHolder *holder, const GValue *value,
 #endif
 
 	/* holder will be changed? */
-	newnull = !value || __gda_value_is_null (value);
+	newnull = !value || GDA_VALUE_HOLDS_NULL (value);
 	current_val = gda_holder_get_value (holder);
 	if (current_val == value)
 		changed = FALSE;
-	else if ((!current_val || __gda_value_is_null (current_val)) && newnull) 
+	else if ((!current_val || GDA_VALUE_HOLDS_NULL (current_val)) && newnull) 
 		changed = FALSE;
 	else if (value && current_val &&
 		 (G_VALUE_TYPE (value) == G_VALUE_TYPE (current_val))) 
@@ -1168,10 +1103,6 @@ real_gda_holder_set_const_value (GdaHolder *holder, const GValue *value,
 	/* end of procedure if the value has not been changed, after calculating the holder's validity */
 	if (!changed) {
 		holder->priv->invalid_forced = FALSE;
-		if (holder->priv->invalid_error) {
-			g_error_free (holder->priv->invalid_error);
-			holder->priv->invalid_error = NULL;
-		}
 		holder->priv->valid = newvalid;
 #ifdef DEBUG_HOLDER		
 		g_print ("Holder is not changed");
@@ -1194,10 +1125,6 @@ real_gda_holder_set_const_value (GdaHolder *holder, const GValue *value,
 
 	/* new valid status */
 	holder->priv->invalid_forced = FALSE;
-	if (holder->priv->invalid_error) {
-		g_error_free (holder->priv->invalid_error);
-		holder->priv->invalid_error = NULL;
-	}
 	holder->priv->valid = newvalid;
 	/* we're setting a static value, so be sure to flag is as unfreeable */
 	holder->priv->is_freeable = FALSE;
@@ -1281,15 +1208,10 @@ GValue *
 gda_holder_take_static_value (GdaHolder *holder, const GValue *value, gboolean *value_changed,
 			      GError **error)
 {
-	GValue *retvalue;
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), FALSE);
 	g_return_val_if_fail (holder->priv, FALSE);
 
-	gda_holder_lock ((GdaLockable*) holder);
-	retvalue = real_gda_holder_set_const_value (holder, value, value_changed, error);
-	gda_holder_unlock ((GdaLockable*) holder);
-
-	return retvalue;
+	return real_gda_holder_set_const_value (holder, value, value_changed, error);
 }
 
 /**
@@ -1303,25 +1225,6 @@ gda_holder_take_static_value (GdaHolder *holder, const GValue *value, gboolean *
  */
 void
 gda_holder_force_invalid (GdaHolder *holder)
-{
-	g_return_if_fail (GDA_IS_HOLDER (holder));
-	gda_holder_force_invalid_e (holder, NULL);
-}
-
-/**
- * gda_holder_force_invalid_e:
- * @holder: a #GdaHolder object
- * @error: (allow-none) (transfer full): a #GError explaining why @holder is declared invalid, or %NULL
- *
- * Forces a holder to be invalid; to set it valid again, a new value must be assigned
- * to it using gda_holder_set_value() or gda_holder_take_value().
- *
- * @holder's value is set to %NULL.
- *
- * Since: 4.2.10
- */
-void
-gda_holder_force_invalid_e (GdaHolder *holder, GError *error)
 {
 	g_return_if_fail (GDA_IS_HOLDER (holder));
 	g_return_if_fail (holder->priv);
@@ -1330,15 +1233,8 @@ gda_holder_force_invalid_e (GdaHolder *holder, GError *error)
 	g_print ("Holder %p (%s): declare invalid\n", holder, holder->priv->id);
 #endif
 
-	gda_holder_lock ((GdaLockable*) holder);
-	if (holder->priv->invalid_error)
-		g_error_free (holder->priv->invalid_error);
-	holder->priv->invalid_error = error;
-
-	if (holder->priv->invalid_forced) {
-		gda_holder_unlock ((GdaLockable*) holder);
+	if (holder->priv->invalid_forced)
 		return;
-	}
 
 	holder->priv->invalid_forced = TRUE;
 	holder->priv->valid = FALSE;
@@ -1353,9 +1249,9 @@ gda_holder_force_invalid_e (GdaHolder *holder, GError *error)
 		gda_holder_force_invalid (holder->priv->full_bind);
 	else 
 		g_signal_emit (holder, gda_holder_signals[CHANGED], 0);
-	gda_holder_unlock ((GdaLockable*) holder);
 }
 
+
 /**
  * gda_holder_is_valid:
  * @holder: a #GdaHolder object
@@ -1367,45 +1263,20 @@ gda_holder_force_invalid_e (GdaHolder *holder, GError *error)
 gboolean
 gda_holder_is_valid (GdaHolder *holder)
 {
-	g_return_val_if_fail (GDA_IS_HOLDER (holder), FALSE);
-	return gda_holder_is_valid_e (holder, NULL);
-}
-
-/**
- * gda_holder_is_valid_e:
- * @holder: a #GdaHolder object
- * @error: (allow-none): a place to store invalid error, or %NULL
- *
- * Get the validity of @holder (that is, of the value held by @holder)
- *
- * Returns: TRUE if @holder's value can safely be used
- *
- * Since: 4.2.10
- */
-gboolean
-gda_holder_is_valid_e (GdaHolder *holder, GError **error)
-{
-	gboolean retval;
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), FALSE);
 	g_return_val_if_fail (holder->priv, FALSE);
 
-	gda_holder_lock ((GdaLockable*) holder);
 	if (holder->priv->full_bind)
-		retval = gda_holder_is_valid_e (holder->priv->full_bind, error);
+		return gda_holder_is_valid (holder->priv->full_bind);
 	else {
 		if (holder->priv->invalid_forced) 
-			retval = FALSE;
-		else {
-			if (holder->priv->default_forced) 
-				retval = holder->priv->default_value ? TRUE : FALSE;
-			else 
-				retval = holder->priv->valid;
-		}
-		if (!retval && holder->priv->invalid_error)
-			g_propagate_error (error,  g_error_copy (holder->priv->invalid_error));
+			return FALSE;
+
+		if (holder->priv->default_forced) 
+			return holder->priv->default_value ? TRUE : FALSE;
+		else 
+			return holder->priv->valid;
 	}
-	gda_holder_unlock ((GdaLockable*) holder);
-	return retval;
 }
 
 /**
@@ -1422,24 +1293,14 @@ gda_holder_set_value_to_default (GdaHolder *holder)
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), FALSE);
 	g_return_val_if_fail (holder->priv, FALSE);
 
-	gda_holder_lock ((GdaLockable*) holder);
-	if (holder->priv->default_forced) {
-		gda_holder_unlock ((GdaLockable*) holder);
+	if (holder->priv->default_forced)
 		return TRUE;
-	}
 
-	if (!holder->priv->default_value) {
-		gda_holder_unlock ((GdaLockable*) holder);
+	if (!holder->priv->default_value)
 		return FALSE;
-	}
 	else {
 		holder->priv->default_forced = TRUE;
 		holder->priv->invalid_forced = FALSE;
-		if (holder->priv->invalid_error) {
-			g_error_free (holder->priv->invalid_error);
-			holder->priv->invalid_error = NULL;
-		}
-
 		if (holder->priv->value) {
 			if (holder->priv->is_freeable)
 				gda_value_free (holder->priv->value);
@@ -1453,7 +1314,6 @@ gda_holder_set_value_to_default (GdaHolder *holder)
 	gda_value_free (att_value);
 	g_signal_emit (holder, gda_holder_signals[CHANGED], 0);
 
-	gda_holder_unlock ((GdaLockable*) holder);
 	return TRUE;
 }
 
@@ -1511,7 +1371,6 @@ gda_holder_set_default_value (GdaHolder *holder, const GValue *value)
 	g_return_if_fail (GDA_IS_HOLDER (holder));
 	g_return_if_fail (holder->priv);
 
-	gda_holder_lock ((GdaLockable*) holder);
 	if (holder->priv->default_value) {
 		if (holder->priv->default_forced) {
 			gda_holder_take_value (holder, holder->priv->default_value, NULL);
@@ -1529,8 +1388,8 @@ gda_holder_set_default_value (GdaHolder *holder, const GValue *value)
 		const GValue *current = gda_holder_get_value (holder);
 
 		/* check if default is equal to current value */
-		if (__gda_value_is_null (value) &&
-		    (!current || __gda_value_is_null (current)))
+		if (GDA_VALUE_HOLDS_NULL (value) &&
+		    (!current || GDA_VALUE_HOLDS_NULL (current)))
 			holder->priv->default_forced = TRUE;
 		else if ((G_VALUE_TYPE (value) == holder->priv->g_type) &&
 			 current && !gda_value_compare (value, current))
@@ -1545,7 +1404,6 @@ gda_holder_set_default_value (GdaHolder *holder, const GValue *value)
 	gda_value_free (att_value);
 
 	/* don't emit the "changed" signal */
-	gda_holder_unlock ((GdaLockable*) holder);
 }
 
 /**
@@ -1609,7 +1467,6 @@ gda_holder_set_source_model (GdaHolder *holder, GdaDataModel *model,
 	/* No check is done on the validity of @col or even its existance */
 	/* Note: for internal implementation if @col<0, then it's ignored */
 
-	gda_holder_lock ((GdaLockable*) holder);
 	if (model && (col >= 0)) {
 		GType htype, ctype;
 		GdaColumn *gcol;
@@ -1624,7 +1481,6 @@ gda_holder_set_source_model (GdaHolder *holder, GdaDataModel *model,
                                                "source column %d type (%s)"),
                                              gda_g_type_to_string (htype),
                                              col, gda_g_type_to_string (ctype));
-				gda_holder_unlock ((GdaLockable*) holder);
 				return FALSE;
 			}
 		}
@@ -1653,8 +1509,6 @@ gda_holder_set_source_model (GdaHolder *holder, GdaDataModel *model,
 #ifdef GDA_DEBUG_signal
         g_print ("<< 'SOURCE_CHANGED' from %p\n", holder);
 #endif
-
-	gda_holder_unlock ((GdaLockable*) holder);
 	return TRUE;
 }
 
@@ -1676,16 +1530,13 @@ gda_holder_set_source_model (GdaHolder *holder, GdaDataModel *model,
 GdaDataModel *
 gda_holder_get_source_model (GdaHolder *holder, gint *col)
 {
-	GdaDataModel *model;
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), FALSE);
 	g_return_val_if_fail (holder->priv, FALSE);
-
-	gda_holder_lock ((GdaLockable*) holder);
+	
 	if (col)
 		*col = holder->priv->source_col;
-	model = holder->priv->source_model;
-	gda_holder_unlock ((GdaLockable*) holder);
-	return model;
+
+	return holder->priv->source_model;
 }
 
 /*
@@ -1695,12 +1546,9 @@ gda_holder_get_source_model (GdaHolder *holder, gint *col)
 static void
 bind_to_notify_cb (GdaHolder *bind_to, G_GNUC_UNUSED GParamSpec *pspec, GdaHolder *holder)
 {
-	gda_holder_lock ((GdaLockable*) holder);
-	gda_holder_lock ((GdaLockable*) bind_to);
-
 	g_signal_handler_disconnect (holder->priv->simple_bind,
-				     holder->priv->simple_bind_type_changed_id);
-	holder->priv->simple_bind_type_changed_id = 0;
+				     holder->priv->simple_bind_notify_signal_id);
+	holder->priv->simple_bind_notify_signal_id = 0;
 	if (holder->priv->g_type == GDA_TYPE_NULL) {
 		holder->priv->g_type = bind_to->priv->g_type;
 		g_object_notify ((GObject*) holder, "g-type");
@@ -1712,9 +1560,6 @@ bind_to_notify_cb (GdaHolder *bind_to, G_GNUC_UNUSED GParamSpec *pspec, GdaHolde
 			   gda_holder_get_id (holder), gda_holder_get_id (bind_to));
 		gda_holder_set_bind (holder, NULL, NULL);
 	}
-
-	gda_holder_unlock ((GdaLockable*) holder);
-	gda_holder_unlock ((GdaLockable*) bind_to);
 }
 
 /**
@@ -1743,11 +1588,8 @@ gda_holder_set_bind (GdaHolder *holder, GdaHolder *bind_to, GError **error)
 	g_return_val_if_fail (holder->priv, FALSE);
 	g_return_val_if_fail (holder != bind_to, FALSE);
 
-	gda_holder_lock ((GdaLockable*) holder);
-	if (holder->priv->simple_bind == bind_to) {
-		gda_holder_unlock ((GdaLockable*) holder);
+	if (holder->priv->simple_bind == bind_to)
 		return TRUE;
-	}
 
 	/* get a copy of the current values of @holder and @bind_to */
 	if (bind_to) {
@@ -1759,7 +1601,6 @@ gda_holder_set_bind (GdaHolder *holder, GdaHolder *bind_to, GError **error)
 		    (holder->priv->g_type != bind_to->priv->g_type)) {
 			g_set_error (error, GDA_HOLDER_ERROR, GDA_HOLDER_VALUE_TYPE_ERROR,
 				     "%s", _("Cannot bind holders if their type is not the same"));
-			gda_holder_unlock ((GdaLockable*) holder);
 			return FALSE;
 		}
 		value2 = gda_holder_get_value (bind_to);
@@ -1771,42 +1612,38 @@ gda_holder_set_bind (GdaHolder *holder, GdaHolder *bind_to, GError **error)
 
 	/* get rid of the old alias */
 	if (holder->priv->simple_bind) {
-		g_signal_handlers_disconnect_by_func (holder->priv->simple_bind,
-						      G_CALLBACK (bound_holder_changed_cb), holder);
-
-		if (holder->priv->simple_bind_type_changed_id) {
+		g_signal_handlers_disconnect_by_func (G_OBJECT (holder->priv->simple_bind),
+						      G_CALLBACK (full_bind_changed_cb), holder);
+		if (holder->priv->simple_bind_notify_signal_id) {
 			g_signal_handler_disconnect (holder->priv->simple_bind,
-						     holder->priv->simple_bind_type_changed_id);
-			holder->priv->simple_bind_type_changed_id = 0;
+						     holder->priv->simple_bind_notify_signal_id);
+			holder->priv->simple_bind_notify_signal_id = 0;
 		}
 		g_object_unref (holder->priv->simple_bind);
 		holder->priv->simple_bind = NULL;
 	}
 
 	/* setting the new alias or reseting the value if there is no new alias */
-	gboolean retval;
 	if (bind_to) {
-		holder->priv->simple_bind = g_object_ref (bind_to);
-		g_signal_connect (holder->priv->simple_bind, "changed",
-				  G_CALLBACK (bound_holder_changed_cb), holder);
+		holder->priv->simple_bind = bind_to;
+		g_object_ref (holder->priv->simple_bind);
+		g_signal_connect (G_OBJECT (holder->priv->simple_bind), "changed",
+				  G_CALLBACK (full_bind_changed_cb), holder);
 
 		if (bind_to->priv->g_type == GDA_TYPE_NULL)
-			holder->priv->simple_bind_type_changed_id = g_signal_connect (bind_to, "notify::g-type",
-										      G_CALLBACK (bind_to_notify_cb),
-										      holder);
+			holder->priv->simple_bind_notify_signal_id = g_signal_connect (bind_to, "notify::g-type",
+										       G_CALLBACK (bind_to_notify_cb),
+										       holder);
 		else if (holder->priv->g_type == GDA_TYPE_NULL)
 			g_object_set ((GObject*) holder, "g-type", bind_to->priv->g_type , NULL);
 
 		/* if bind_to has a different value than holder, then we set holder to the new value */
 		if (value1)
 			gda_value_free (value1);
-		retval = gda_holder_set_value (holder, value2, error);
+		return gda_holder_set_value (holder, value2, error);
 	}
 	else
-		retval = gda_holder_take_value (holder, value1, error);
-
-	gda_holder_unlock ((GdaLockable*) holder);
-	return retval;
+		return gda_holder_take_value (holder, value1, error);
 }
 
 /*
@@ -1827,11 +1664,8 @@ gda_holder_set_full_bind (GdaHolder *holder, GdaHolder *alias_of)
 	g_return_if_fail (GDA_IS_HOLDER (holder));
 	g_return_if_fail (holder->priv);
 
-	gda_holder_lock ((GdaLockable*) holder);
-	if (holder->priv->full_bind == alias_of) {
-		gda_holder_unlock ((GdaLockable*) holder);
+	if (holder->priv->full_bind == alias_of)
 		return;
-	}
 
 	/* get a copy of the current values of @holder and @alias_of */
 	if (alias_of) {
@@ -1839,18 +1673,19 @@ gda_holder_set_full_bind (GdaHolder *holder, GdaHolder *alias_of)
 		g_return_if_fail (alias_of->priv);
 		g_return_if_fail (holder->priv->g_type == alias_of->priv->g_type);
 		cvalue = gda_holder_get_value (alias_of);
-		if (cvalue && !__gda_value_is_null ((GValue*)cvalue))
+		if (cvalue && !GDA_VALUE_HOLDS_NULL ((GValue*)cvalue))
 			value2 = gda_value_copy ((GValue*)cvalue);
 	}
 
 	cvalue = gda_holder_get_value (holder);
-	if (cvalue && !__gda_value_is_null ((GValue*)cvalue))
+	if (cvalue && !GDA_VALUE_HOLDS_NULL ((GValue*)cvalue))
 		value1 = gda_value_copy ((GValue*)cvalue);
+		
 	
 	/* get rid of the old alias */
 	if (holder->priv->full_bind) {
-		g_signal_handlers_disconnect_by_func (holder->priv->full_bind,
-						      G_CALLBACK (full_bound_holder_changed_cb), holder);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (holder->priv->full_bind),
+						      G_CALLBACK (full_bind_changed_cb), holder);
 		g_object_unref (holder->priv->full_bind);
 		holder->priv->full_bind = NULL;
 	}
@@ -1866,9 +1701,10 @@ gda_holder_set_full_bind (GdaHolder *holder, GdaHolder *alias_of)
 			holder->priv->value = NULL;
 		}
 
-		holder->priv->full_bind = g_object_ref (alias_of);
-		g_signal_connect (holder->priv->full_bind, "changed",
-				  G_CALLBACK (full_bound_holder_changed_cb), holder);
+		holder->priv->full_bind = alias_of;
+		g_object_ref (alias_of);
+		g_signal_connect (G_OBJECT (alias_of), "changed",
+				  G_CALLBACK (full_bind_changed_cb), holder);
 
 		/* if alias_of has a different value than holder, then we emit a CHANGED signal */
 		if (value1 && value2 &&
@@ -1893,40 +1729,24 @@ gda_holder_set_full_bind (GdaHolder *holder, GdaHolder *alias_of)
 
 	if (value1) gda_value_free (value1);
 	if (value2) gda_value_free (value2);
-	gda_holder_unlock ((GdaLockable*) holder);
 }
 
 static void
-full_bound_holder_changed_cb (GdaHolder *alias_of, GdaHolder *holder)
+full_bind_changed_cb (GdaHolder *alias_of, GdaHolder *holder)
 {
-	gda_holder_lock ((GdaLockable*) holder);
-	gda_holder_lock ((GdaLockable*) alias_of);
-
-	g_assert (alias_of == holder->priv->full_bind);
-	g_signal_emit (holder, gda_holder_signals [CHANGED], 0);
-
-	gda_holder_unlock ((GdaLockable*) holder);
-	gda_holder_unlock ((GdaLockable*) alias_of);
-}
-
-static void
-bound_holder_changed_cb (GdaHolder *alias_of, GdaHolder *holder)
-{
-	gda_holder_lock ((GdaLockable*) holder);
-	gda_holder_lock ((GdaLockable*) alias_of);
-
-	g_assert (alias_of == holder->priv->simple_bind);
-	const GValue *cvalue;
-	GError *lerror = NULL;
-	cvalue = gda_holder_get_value (alias_of);
-	if (! gda_holder_set_value (holder, cvalue, &lerror)) {
-		if (lerror && ((lerror->domain != GDA_HOLDER_ERROR) || (lerror->code != GDA_HOLDER_VALUE_NULL_ERROR)))
-			g_warning (_("Could not change GdaHolder to match value change in bound GdaHolder: %s"),
-				   lerror && lerror->message ? lerror->message : _("No detail"));
-		g_clear_error (&lerror);
+	if (alias_of == holder->priv->simple_bind) {
+		const GValue *cvalue;
+		GError *lerror = NULL;
+		cvalue = gda_holder_get_value (alias_of);
+		if (! gda_holder_set_value (holder, cvalue, &lerror)) {
+			if (lerror && ((lerror->domain != GDA_HOLDER_ERROR) || (lerror->code != GDA_HOLDER_VALUE_NULL_ERROR)))
+				g_warning (_("Could not change GdaHolder to match value change in bound GdaHolder: %s"),
+					   lerror && lerror->message ? lerror->message : _("No detail"));
+			g_clear_error (&lerror);
+		}
 	}
-	gda_holder_unlock ((GdaLockable*) holder);
-	gda_holder_unlock ((GdaLockable*) alias_of);
+	else
+		g_signal_emit (holder, gda_holder_signals [CHANGED], 0);
 }
 
 /**
@@ -2016,36 +1836,11 @@ gda_holder_set_attribute (GdaHolder *holder, const gchar *attribute, const GValu
 	const GValue *cvalue;
 	g_return_if_fail (GDA_IS_HOLDER (holder));
 
-	gda_holder_lock ((GdaLockable*) holder);
 	cvalue = gda_attributes_manager_get (gda_holder_attributes_manager, holder, attribute);
 	if ((value && cvalue && !gda_value_differ (cvalue, value)) ||
-	    (!value && !cvalue)) {
-		gda_holder_unlock ((GdaLockable*) holder);
+	    (!value && !cvalue))
 		return;
-	}
 
 	gda_attributes_manager_set_full (gda_holder_attributes_manager, holder, attribute, value, destroy);
 	//g_print ("GdaHolder %p ATTR '%s' set to '%s'\n", holder, attribute, gda_value_stringify (value)); 
-	gda_holder_unlock ((GdaLockable*) holder);
-}
-
-static void
-gda_holder_lock (GdaLockable *lockable)
-{
-	GdaHolder *holder = (GdaHolder *) lockable;
-	gda_mutex_lock (holder->priv->mutex);
-}
-
-static gboolean
-gda_holder_trylock (GdaLockable *lockable)
-{
-	GdaHolder *holder = (GdaHolder *) lockable;
-	return gda_mutex_trylock (holder->priv->mutex);
-}
-
-static void
-gda_holder_unlock (GdaLockable *lockable)
-{
-	GdaHolder *holder = (GdaHolder *) lockable;
-	gda_mutex_unlock (holder->priv->mutex);
 }
