@@ -1,25 +1,34 @@
 /*
- * Copyright (C) 1998 - 2011 The GNOME Foundation.
+ * Copyright (C) 2001 - 2003 Rodrigo Moya <rodrigo@gnome-db.org>
+ * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
+ * Copyright (C) 2003 - 2004 Laurent Sansonetti <lrz@gnome.org>
+ * Copyright (C) 2003 Paisa Seeluangsawat <paisa@users.sf.net>
+ * Copyright (C) 2004 Caolan McNamara <caolanm@redhat.com>
+ * Copyright (C) 2004 Jrg Billeter <j@bitron.ch>
+ * Copyright (C) 2004 - 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2009 Armin Burgmeier <armin@openismus.com>
+ * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2008 Phil Longstaff <plongstaff@rogers.com>
+ * Copyright (C) 2008 Przemysław Grzegorczyk <pgrzegorczyk@gmail.com>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
+ * Copyright (C) 2011 Daniel Espinosa <esodan@gmail.com>
  *
- * AUTHORS:
- *	Rodrigo Moya <rodrigo@gnome-db.org>
- *	Juan-Mariano de Goyeneche <jmseyas@dit.upm.es> (BLOB issues)
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #undef GDA_DISABLE_DEPRECATED
@@ -687,9 +696,7 @@ gda_utility_holder_load_attributes (GdaHolder *holder, xmlNodePtr node, GSList *
 	if (vnode) {
 		xmlChar *this_lang, *isnull;
 		const gchar *lang = gda_lang_locale;
-		GType gdatype;
 
-		gdatype = gda_holder_get_g_type (holder);
 		while (vnode) {
 			if (xmlNodeIsText (vnode)) {
 				vnode = vnode->next;
@@ -975,7 +982,7 @@ gda_compute_unique_table_row_condition_with_cnc (GdaConnection *cnc, GdaSqlState
 				opexpr = gda_sql_expr_new (GDA_SQL_ANY_PART (op));
 				pspec = g_new0 (GdaSqlParamSpec, 1);
 				pspec->name = g_strdup_printf ("-%d", index);
-				pspec->g_type = tcol->gtype != G_TYPE_INVALID ? tcol->gtype: G_TYPE_STRING;
+				pspec->g_type = (tcol->gtype != GDA_TYPE_NULL) ? tcol->gtype: G_TYPE_STRING;
 				pspec->nullok = tcol->nullok;
 				opexpr->param_spec = pspec;
 				op->operands = g_slist_append (op->operands, opexpr);
@@ -1169,7 +1176,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		if (insert_stmt) {
 			GdaSqlParamSpec *pspec = g_new0 (GdaSqlParamSpec, 1);
 			pspec->name = g_strdup_printf ("+%d", colindex);
-			pspec->g_type = tcol->gtype != G_TYPE_INVALID ? tcol->gtype: G_TYPE_STRING;
+			pspec->g_type = (tcol->gtype != GDA_TYPE_NULL) ? tcol->gtype: G_TYPE_STRING;
 			pspec->nullok = tcol->nullok;
 			expr = gda_sql_expr_new (GDA_SQL_ANY_PART (ist));
 			expr->param_spec = pspec;
@@ -1178,7 +1185,7 @@ gda_compute_dml_statements (GdaConnection *cnc, GdaStatement *select_stmt, gbool
 		if (update_stmt) {
 			GdaSqlParamSpec *pspec = g_new0 (GdaSqlParamSpec, 1);
 			pspec->name = g_strdup_printf ("+%d", colindex);
-			pspec->g_type = tcol->gtype != G_TYPE_INVALID ? tcol->gtype: G_TYPE_STRING;
+			pspec->g_type = (tcol->gtype != GDA_TYPE_NULL) ? tcol->gtype: G_TYPE_STRING;
 			pspec->nullok = tcol->nullok;
 			expr = gda_sql_expr_new (GDA_SQL_ANY_PART (ust));
 			expr->param_spec = pspec;
@@ -2362,7 +2369,6 @@ gboolean
 gda_rfc1738_decode (gchar *string)
 {
 	gchar *wptr, *rptr;
-	gboolean retval = TRUE;
 
 	if (!string || !*string)
 		return TRUE;
@@ -2399,7 +2405,7 @@ gda_rfc1738_decode (gchar *string)
 			}
 			else {
 				/* error */
-				retval = FALSE;
+				/* TODO: Actually return this? retval = FALSE; murrayc */
 				rptr--;
 			}
 		}
