@@ -1,21 +1,24 @@
-/* gda-handler-time.c
+/*
+ * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
  *
- * Copyright (C) 2003 - 2010 Vivien Malerba
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include "gda-handler-time.h"
@@ -358,7 +361,7 @@ handler_compute_locale (GdaHandlerTime *hdl)
 		time_t now;
 		struct tm *now_tm;
 
-		for (i=0; i<3; i++) {
+		for (i=0; i < 3; i++) {
 			switch (nums[i]) {
 			case 7:
 				hdl->priv->str_locale->dmy_order[i] = G_DATE_MONTH;
@@ -377,7 +380,16 @@ handler_compute_locale (GdaHandlerTime *hdl)
 		}
 		
 		now = time (NULL);
-		now_tm = localtime (&now);
+#ifdef HAVE_LOCALTIME_R
+		struct tm tmpstm;
+		now_tm = localtime_r (&now, &tmpstm);
+#elif HAVE_LOCALTIME_S
+		struct tm tmpstm;
+		g_assert (localtime_s (&tmpstm, &now) == 0);
+		now_tm = &tmpstm;
+#else
+                now_tm = localtime (&now);
+#endif
 		hdl->priv->str_locale->current_offset = ((now_tm->tm_year + 1900) / 100) * 100;
 
 #ifdef GDA_DEBUG_NO		
@@ -1118,7 +1130,16 @@ gda_handler_time_get_sane_init_value (GdaDataHandler *iface, GType type)
 	g_return_val_if_fail (hdl->priv, NULL);
 
 	now = time (NULL);
+#ifdef HAVE_LOCALTIME_R
+	struct tm tmpstm;
+	stm = localtime_r (&now, &tmpstm);
+#elif HAVE_LOCALTIME_S
+	struct tm tmpstm;
+	g_assert (localtime_s (&tmpstm, &now) == 0);
+	stm = &tmpstm;
+#else
 	stm = localtime (&now);
+#endif
 
 	if (type == G_TYPE_DATE) {
 		GDate *gdate;
@@ -1165,7 +1186,6 @@ gda_handler_time_accepts_g_type (GdaDataHandler *iface, GType type)
 	gboolean found = FALSE;
 
 	g_return_val_if_fail (iface && GDA_IS_HANDLER_TIME (iface), FALSE);
-	g_return_val_if_fail (type != G_TYPE_INVALID, FALSE);
 	hdl = GDA_HANDLER_TIME (iface);
 	g_return_val_if_fail (hdl->priv, 0);
 
