@@ -940,7 +940,6 @@ keywordCode (GdaSqlParser *parser, gchar *str, gint len)
 		g_hash_table_insert (keywords, "full", GINT_TO_POINTER (L_FULL));
 		g_hash_table_insert (keywords, "group", GINT_TO_POINTER (L_GROUP));
 		g_hash_table_insert (keywords, "having", GINT_TO_POINTER (L_HAVING));
-		g_hash_table_insert (keywords, "ilike", GINT_TO_POINTER (L_ILIKE));
 		g_hash_table_insert (keywords, "immediate", GINT_TO_POINTER (L_IMMEDIATE));
 		g_hash_table_insert (keywords, "in", GINT_TO_POINTER (L_IN));
 		g_hash_table_insert (keywords, "inner", GINT_TO_POINTER (L_INNER));
@@ -1494,7 +1493,7 @@ getToken (GdaSqlParser *parser)
 				else {
 					for (i=1; z[i] && (! isspace (z[i])) &&
 						     (z[i] != parser->priv->context->delimiter) && (z[i] != '*') &&
-						     (z[i] != '\'') && (z[i] != '"') && (z[i] != '#'); i++){}
+						     (z[i] != '\'') && (z[i] != '"'); i++){}
 					parser->priv->context->token_type = L_RAWSTRING;
 					consumed_chars = i;
 				}
@@ -1527,8 +1526,6 @@ getToken (GdaSqlParser *parser)
 		g_print ("%d (%s)\n", parser->priv->context->token_type, str);
 		g_free (str);
 	}
-	else if (parser->priv->context->token_type == L_END_OF_FILE)
-		g_print ("%d (END OF FILE)\n", parser->priv->context->token_type);
 	else
 		g_print ("%d\n", parser->priv->context->token_type);
 #endif
