@@ -1,20 +1,22 @@
-/* 
- * Copyright (C) 2007 - 2011 Vivien Malerba
+/*
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -26,7 +28,7 @@
 /**
  * gda_sql_param_spec_take_name:
  * @pspec: a #GdaSqlParamSpec pointer
- * @value: a G_TYPE_STRING #GValue
+ * @value: (transfer full): a G_TYPE_STRING #GValue
  *
  * Sets @pspec's name. @value's ownership is transferred to
  * @pspec (which means @pspec is then responsible for freeing it when no longer needed).
@@ -40,15 +42,14 @@ gda_sql_param_spec_take_name (GdaSqlParamSpec *pspec, GValue *value)
 	}
 	if (value) {
 		pspec->name = _remove_quotes (g_value_dup_string (value));
-		g_value_unset (value);
-		g_free (value);
+		gda_value_free (value);
 	}
 }
 
 /**
  * gda_sql_param_spec_take_descr:
  * @pspec: a #GdaSqlParamSpec pointer
- * @value: a G_TYPE_STRING #GValue
+ * @value: (transfer full): a G_TYPE_STRING #GValue
  *
  * Sets @pspec's description. @value's ownership is transferred to
  * @pspec (which means @pspec is then responsible for freeing it when no longer needed).
@@ -62,15 +63,14 @@ gda_sql_param_spec_take_descr (GdaSqlParamSpec *pspec, GValue *value)
 	}
 	if (value) {
 		pspec->descr = _remove_quotes (g_value_dup_string (value));
-		g_value_unset (value);
-		g_free (value);
+		gda_value_free (value);
 	}
 }
 
 /**
  * gda_sql_param_spec_take_nullok:
  * @pspec: a #GdaSqlParamSpec pointer
- * @value: a G_TYPE_STRING #GValue. 
+ * @value: (transfer full): a G_TYPE_STRING #GValue. 
  *
  * Sets @pspec's ability of being NULL. @value's ownership is transferred to
  * @pspec (which means @pspec is then responsible for freeing it when no longer needed).
@@ -88,15 +88,14 @@ gda_sql_param_spec_take_nullok (GdaSqlParamSpec *pspec, GValue *value)
 			if ((*str == 't') || (*str == 'T'))
 				pspec->nullok = TRUE;
 		}
-		g_value_unset (value);
-		g_free (value);
+		gda_value_free (value);
 	}
 }
 
 /**
  * gda_sql_param_spec_take_type:
  * @pspec: a #GdaSqlParamSpec pointer
- * @value: a G_TYPE_STRING #GValue
+ * @value: (transfer full): a G_TYPE_STRING #GValue
  *
  * Sets @pspec's data type. @value's ownership is transferred to
  * @pspec (which means @pspec is then responsible for freeing it when no longer needed).
@@ -106,12 +105,11 @@ gda_sql_param_spec_take_nullok (GdaSqlParamSpec *pspec, GValue *value)
 void
 gda_sql_param_spec_take_type (GdaSqlParamSpec *pspec, GValue *value)
 {
-	pspec->g_type = 0;
+	pspec->g_type = GDA_TYPE_NULL;
 	if (value) {
 		gchar *tmp;
 		tmp = _remove_quotes (g_value_dup_string (value));
-		g_value_unset (value);
-		g_free (value);
+		gda_value_free (value);
 
 		pspec->g_type = gda_g_type_from_string (tmp);
 		g_free (tmp);
@@ -120,7 +118,7 @@ gda_sql_param_spec_take_type (GdaSqlParamSpec *pspec, GValue *value)
 
 /**
  * gda_sql_param_spec_new:
- * @value: a G_TYPE_STRING #GValue
+ * @value: (transfer full): a G_TYPE_STRING #GValue
  *
  * @value must contain a string representing a variable, see the documentation associated to the
  * #GdaSqlParser object.
@@ -137,6 +135,7 @@ gda_sql_param_spec_new (GValue *value)
 	pspec =g_new0 (GdaSqlParamSpec, 1);
 	pspec->is_param = TRUE;
 	pspec->nullok = FALSE;
+	pspec->g_type = GDA_TYPE_NULL;
 
 	if (value) {
 		gchar *str = (gchar *) g_value_get_string (value);
@@ -166,8 +165,7 @@ gda_sql_param_spec_new (GValue *value)
 				str = ptr;
 			}
 		}
-		g_value_unset (value);
-		g_free (value);
+		gda_value_free (value);
 	}
 
 	return pspec;
@@ -242,7 +240,7 @@ gda_sql_param_spec_serialize (GdaSqlParamSpec *pspec)
 	g_string_append_printf (string, ",\"descr\":%s", str);
 	g_free (str);
 
-	if (pspec->g_type != G_TYPE_INVALID) {
+	if (pspec->g_type != GDA_TYPE_NULL) {
 		str = _json_quote_string (gda_g_type_to_string (pspec->g_type));
 		g_string_append_printf (string, ",\"type\":%s", str);
 		g_free (str);
