@@ -251,7 +251,7 @@ gda_vconnection_data_model_add_model (GdaVconnectionDataModel *cnc,
  * gda_vconnection_data_model_add:
  * @cnc: a #GdaVconnectionDataModel connection
  * @spec: a #GdaVconnectionDataModelSpec structure, used AS IS (not copied) and can be modified
- * @spec_free_func: (allow-none): function to call when freeing @spec, or %NULL
+ * @spec_free_func: function to call when freeing @spec, or %NULL
  * @table_name: the name of the table
  * @error: a place to store errors, or %NULL
  *
@@ -320,9 +320,7 @@ gda_vconnection_data_model_add (GdaVconnectionDataModel *cnc, GdaVconnectionData
 	rc = SQLITE3_CALL (sqlite3_exec) (scnc->connection, str, NULL, 0, &zErrMsg);
 	g_free (str);
 	if (rc != SQLITE_OK) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_INTERNAL_ERROR,
-			     "%s", zErrMsg);
+		g_set_error (error, 0, 0, "%s", zErrMsg);
 		SQLITE3_CALL (sqlite3_free) (zErrMsg);
 		gda_vconnection_data_model_table_data_free (td);
 		cnc->priv->table_data_list = g_slist_remove (cnc->priv->table_data_list, td);
@@ -354,7 +352,6 @@ gda_vconnection_data_model_remove (GdaVconnectionDataModel *cnc, const gchar *ta
 {
 	GdaVConnectionTableData *td;
 
-	GdaVirtualProvider *prov;
 	gchar *str;
 	int rc;
 	char *zErrMsg = NULL;
@@ -370,21 +367,17 @@ gda_vconnection_data_model_remove (GdaVconnectionDataModel *cnc, const gchar *ta
 
 	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (!td) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
-			     "%s", _("Table to remove not found"));
+		g_set_error (error, 0, 0, "%s",
+			     _("Table to remove not found"));
 		return FALSE;
 	}
-	
-	prov = (GdaVirtualProvider *) gda_connection_get_provider (GDA_CONNECTION (cnc));
+
 	str = g_strdup_printf ("DROP TABLE %s", td->table_name);
 	rc = SQLITE3_CALL (sqlite3_exec) (scnc->connection, str, NULL, 0, &zErrMsg);
 	g_free (str);
 
 	if (rc != SQLITE_OK) {
-		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
-			     GDA_SERVER_PROVIDER_INTERNAL_ERROR,
-			     "%s", zErrMsg);
+		g_set_error (error, 0, 0, "%s", zErrMsg);
 		SQLITE3_CALL (sqlite3_free) (zErrMsg);
 		return FALSE;
 	}
