@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -962,8 +962,8 @@ static const gchar*
 gda_jdbc_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnection *cnc, GType type)
 {
 	if (cnc) {
-		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
+		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, NULL);
 	}
 
 	TO_IMPLEMENT;
@@ -989,11 +989,9 @@ gda_jdbc_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnect
 	if ((type == G_TYPE_DATE) || 
 	    (type == GDA_TYPE_GEOMETRIC_POINT) ||
 	    (type == G_TYPE_OBJECT) ||
-	    (type == GDA_TYPE_LIST) ||
 	    (type == G_TYPE_STRING) ||
 	    (type == GDA_TYPE_TIME) ||
 	    (type == GDA_TYPE_TIMESTAMP) ||
-	    (type == G_TYPE_INVALID) ||
 	    (type == G_TYPE_GTYPE))
 		return "string";
 
@@ -1009,6 +1007,10 @@ gda_jdbc_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnect
 	if (type == G_TYPE_DATE)
 		return "date";
 
+	if ((type == GDA_TYPE_NULL) ||
+	    (type == G_TYPE_GTYPE))
+		return NULL;
+
 	return "text";
 }
 
@@ -1146,7 +1148,7 @@ gda_jdbc_provider_statement_prepare (GdaServerProvider *provider, GdaConnection
 		
 		GValue *jexec_res;
 		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__declareParamTypes,
-						     pstmt_obj, NULL, NULL, error, (jlong)GPOINTER_TO_INT(cnc), jtypes);
+						     pstmt_obj, NULL, NULL, error, (jlong) cnc, jtypes);
 		(*jenv)->DeleteLocalRef (jenv, jtypes);
 		g_free (ctypes);
 		
@@ -1318,23 +1320,7 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 			}
 		}
 		if (!h) {
-			if (allow_noparam) {
-                                /* bind param to NULL */
-				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
-				if (!jexec_res) {
-					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-					if (lerror)
-						gda_connection_event_set_description (event,
-						lerror->message ? lerror->message : _("No detail"));
-					g_propagate_error (error, lerror);
-					break;
-				}
-				gda_value_free (jexec_res);
-                                empty_rs = TRUE;
-                                continue;
-			}
-			else {
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Missing parameter '%s' to execute query"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1343,11 +1329,8 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
-                        }
-
-		}
-		if (!gda_holder_is_valid (h)) {
-			if (allow_noparam) {
+			}
+			else {
                                 /* bind param to NULL */
 				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
 								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
@@ -1362,8 +1345,11 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 				gda_value_free (jexec_res);
                                 empty_rs = TRUE;
                                 continue;
-			}
-			else {
+                        }
+
+		}
+		if (!gda_holder_is_valid (h)) {
+			if (! allow_noparam) {
 				gchar *str;
 				str = g_strdup_printf (_("Parameter '%s' is invalid"), pname);
 				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
@@ -1372,6 +1358,22 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 					     GDA_SERVER_PROVIDER_MISSING_PARAM_ERROR, "%s", str);
 				g_free (str);
 				break;
+			}
+			else {
+                                /* bind param to NULL */
+				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+								     ps->pstmt_obj, NULL, NULL, &lerror, i, 0);
+				if (!jexec_res) {
+					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+					if (lerror)
+						gda_connection_event_set_description (event,
+						lerror->message ? lerror->message : _("No detail"));
+					g_propagate_error (error, lerror);
+					break;
+				}
+				gda_value_free (jexec_res);
+                                empty_rs = TRUE;
+                                continue;
                         }
 		}
 		else if (gda_holder_value_is_default (h) && !gda_holder_get_value (h)) {
@@ -1407,63 +1409,19 @@ gda_jdbc_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 
 		/* actual binding using the C API, for parameter at position @i */
 		const GValue *value = gda_holder_get_value (h);
-		if (!value || gda_value_is_null (value)) {
-			GdaStatement *rstmt;
-			if (! gda_rewrite_statement_for_null_parameters (stmt, params, &rstmt, error)) {
-				jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-								     ps->pstmt_obj, NULL, NULL, &lerror, i, 
-								     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
-				if (!jexec_res) {
-					event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-					if (lerror)
-						gda_connection_event_set_description (event,
-										      lerror->message ? lerror->message : _("No detail"));
-					
-					g_propagate_error (error, lerror);
-					break;
-				}
-				gda_value_free (jexec_res);
-			}
-			else if (!rstmt)
-				return NULL;
-			else {
-				GObject *obj;
-				g_object_unref (ps);
-				_gda_jdbc_release_jenv (jni_detach);
-				obj = gda_jdbc_provider_statement_execute (provider, cnc,
-									   rstmt, params,
-									   model_usage,
-									   col_types,
-									   last_inserted_row,
-									   task_id, async_cb,
-									   cb_data, error);
-				g_object_unref (rstmt);
-				if (GDA_IS_DATA_SELECT (obj)) {
-					GdaPStmt *pstmt;
-					g_object_get (obj, "prepared-stmt", &pstmt, NULL);
-					if (pstmt) {
-						gda_pstmt_set_gda_statement (pstmt, stmt);
-						g_object_unref (pstmt);
-					}
-				}
-				return obj;
-			}
-		}
-		else {
-			jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
-							     ps->pstmt_obj, NULL, NULL, &lerror, i, 
-							     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
-			if (!jexec_res) {
-				event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
-				if (lerror)
-					gda_connection_event_set_description (event,
-									      lerror->message ? lerror->message : _("No detail"));
-				
-				g_propagate_error (error, lerror);
-				break;
-			}
-			gda_value_free (jexec_res);
+		jexec_res = jni_wrapper_method_call (jenv, GdaJPStmt__setParameterValue,
+						     ps->pstmt_obj, NULL, NULL, &lerror, i, 
+						     (G_VALUE_TYPE (value) == GDA_TYPE_NULL) ? (glong) 0 : (glong) value);
+		if (!jexec_res) {
+			event = gda_connection_point_available_event (cnc, GDA_CONNECTION_EVENT_ERROR);
+			if (lerror)
+				gda_connection_event_set_description (event,
+								      lerror->message ? lerror->message : _("No detail"));
+
+			g_propagate_error (error, lerror);
+			break;
 		}
+		gda_value_free (jexec_res);
 	}
 		
 	if (event) {
