@@ -66,8 +66,7 @@ gda_mysql_handler_boolean_get_type (void)
 			NULL,
 			sizeof (GdaMysqlHandlerBoolean),
 			0,
-			(GInstanceInitFunc) gda_mysql_handler_boolean_init,
-			NULL
+			(GInstanceInitFunc) gda_mysql_handler_boolean_init
 		};		
 
 		static const GInterfaceInfo data_entry_info = {
@@ -192,7 +191,7 @@ gda_mysql_handler_boolean_get_str_from_value (GdaDataHandler *iface, const GValu
 }
 
 static GValue *
-gda_mysql_handler_boolean_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, G_GNUC_UNUSED GType type)
+gda_mysql_handler_boolean_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, GType type)
 {
 	GdaMysqlHandlerBoolean *hdl;
 	GValue *value;
@@ -210,7 +209,7 @@ gda_mysql_handler_boolean_get_value_from_sql (GdaDataHandler *iface, const gchar
 }
 
 static GValue *
-gda_mysql_handler_boolean_get_value_from_str (GdaDataHandler *iface, const gchar *str, G_GNUC_UNUSED GType type)
+gda_mysql_handler_boolean_get_value_from_str (GdaDataHandler *iface, const gchar *str, GType type)
 {
 	GdaMysqlHandlerBoolean *hdl;
 	GValue *value = NULL;
@@ -230,7 +229,7 @@ gda_mysql_handler_boolean_get_value_from_str (GdaDataHandler *iface, const gchar
 
 
 static GValue *
-gda_mysql_handler_boolean_get_sane_init_value (GdaDataHandler *iface, G_GNUC_UNUSED GType type)
+gda_mysql_handler_boolean_get_sane_init_value (GdaDataHandler *iface, GType type)
 {
 	GdaMysqlHandlerBoolean *hdl;
 	GValue *value;
@@ -253,7 +252,6 @@ gda_mysql_handler_boolean_accepts_g_type (GdaDataHandler *iface, GType type)
 	gboolean found = FALSE;
 
 	g_return_val_if_fail (GDA_IS_MYSQL_HANDLER_BOOLEAN (iface), FALSE);
-	g_return_val_if_fail (type != G_TYPE_INVALID, FALSE);
 	hdl = GDA_MYSQL_HANDLER_BOOLEAN (iface);
 	g_return_val_if_fail (hdl->priv, 0);
 
