@@ -271,10 +271,7 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 				node = gda_server_operation_get_node_info (op, "/FKEY_S/%d/FKEY_FIELDS_A", i);
 				if (!node || ((nbfields = gda_data_model_get_n_rows (node->model)) == 0)) {
 					allok = FALSE;
-					g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-						     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
-						     "%s",
-						     _("No field specified in foreign key constraint"));
+					g_set_error (error, 0, 0, "%s", _("No field specified in foreign key constraint"));
 				}
 				else {
 					for (j = 0; j < nbfields; j++) {
@@ -288,9 +285,7 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 						}
 						else {
 							allok = FALSE;
-							g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-								     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
-								     "%s",  
+							g_set_error (error, 0, 0, "%s",  
 								     _("Empty field specified in foreign key constraint"));
 						}
 					}
@@ -305,10 +300,7 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 				}
 				else {
 					allok = FALSE;
-					g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-						     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
-						     "%s",
-						     _("No referenced table specified in foreign key constraint"));
+					g_set_error (error, 0, 0, "%s", _("No referenced table specified in foreign key constraint"));
 				}
 
 				g_string_append (string, " (");
@@ -323,9 +315,7 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 					}
 					else {
 						allok = FALSE;
-						g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-							     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
-							     "%s",  
+						g_set_error (error, 0, 0, "%s",  
 							     _("Empty referenced field specified in foreign key constraint"));
 					}
 				}
@@ -372,9 +362,7 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 
 	if (!hasfields) {
 		allok = FALSE;
-		g_set_error (error, GDA_SERVER_OPERATION_ERROR,
-                             GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
-			     "%s", _("Table to create must have at least one row"));
+		g_set_error (error, 0, 0, "%s", _("Table to create must have at least one row"));
 	}
 
 	if (allok) {
@@ -946,6 +934,9 @@ gda_postgres_render_CREATE_USER (GdaServerProvider *provider, GdaConnection *cnc
 	
 	value = gda_server_operation_get_value_at (op, "/USER_DEF_P/VALIDITY");
 	if (value && G_VALUE_HOLDS (value, GDA_TYPE_TIMESTAMP)) {
+		const GdaTimestamp *ts;
+
+		ts = gda_value_get_timestamp (value);
 		if (value) {
 			GdaDataHandler *dh;
 			if (!with) {
