@@ -104,7 +104,7 @@ TestFunc tests[] = {
 int
 main (int argc, char **argv)
 {
-	guint i, ntests = 0, number_failed = 0;
+	gint i, ntests = 0, number_failed = 0;
 	GdaConnection *cnc;
 
 	gda_init ();
