@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -504,10 +521,8 @@ wrapper_callback (GdaThreadWrapper *wrapper, gpointer instance, const gchar *sig
 	for (i = 0; i < n_param_values; i++) {
 		GValue *dest = ts->param_values + i;
 		const GValue *src = param_values + i;
-		if (G_VALUE_TYPE (src) != GDA_TYPE_NULL) {
-			g_value_init (dest, G_VALUE_TYPE (src));
-			g_value_copy (src, dest);
-		}
+		g_value_init (dest, G_VALUE_TYPE (src));
+		g_value_copy (src, dest);
 	}
 	*sig_list = g_slist_append (*sig_list, ts);
 }
@@ -526,13 +541,13 @@ t2_main_thread_func (DummyObject *dummy)
 	GSList *received_list = NULL;
 
 	/*g_print ("NEW test thread: %p\n", g_thread_self());*/
-	sigid[0] = gda_thread_wrapper_connect_raw (wrapper, dummy, "sig0", TRUE,
+	sigid[0] = gda_thread_wrapper_connect_raw (wrapper, dummy, "sig0", TRUE, TRUE,
 						   (GdaThreadWrapperCallback) wrapper_callback,
 						   &received_list);
-	sigid[1] = gda_thread_wrapper_connect_raw (wrapper, dummy, "sig1", TRUE,
+	sigid[1] = gda_thread_wrapper_connect_raw (wrapper, dummy, "sig1", TRUE, TRUE,
 						   (GdaThreadWrapperCallback) wrapper_callback,
 						   &received_list);
-	sigid[2] = gda_thread_wrapper_connect_raw (wrapper, dummy, "sig2", TRUE,
+	sigid[2] = gda_thread_wrapper_connect_raw (wrapper, dummy, "sig2", TRUE, TRUE,
 						   (GdaThreadWrapperCallback) wrapper_callback,
 						   &received_list);
 
