@@ -1,10 +1,11 @@
 /*
- * Copyright (C) 2010 - 2011 Vivien Malerba
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -64,6 +64,14 @@ struct _UiFormGridPriv
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
+/* signals */
+enum {
+        DATA_SET_CHANGED,
+        LAST_SIGNAL
+};
+
+gint ui_formgrid_signals [LAST_SIGNAL] = { 0 };
+
 /* properties */
 enum {
 	PROP_0,
@@ -99,13 +107,23 @@ ui_formgrid_get_type (void)
 }
 
 static void
-ui_formgrid_class_init (UiFormGridClass *class)
+ui_formgrid_class_init (UiFormGridClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	
-	parent_class = g_type_class_peek_parent (class);
+	parent_class = g_type_class_peek_parent (klass);
 	object_class->dispose = ui_formgrid_dispose;
-	GTK_WIDGET_CLASS (class)->show = ui_formgrid_show;
+	GTK_WIDGET_CLASS (klass)->show = ui_formgrid_show;
+
+	/* signals */
+	ui_formgrid_signals [DATA_SET_CHANGED] = 
+		g_signal_new ("data-set-changed",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (UiFormGridClass, data_set_changed),
+                              NULL, NULL,
+                              g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+	klass->data_set_changed = NULL;
 
 	/* Properties */
         object_class->set_property = ui_formgrid_set_property;
@@ -658,6 +676,12 @@ static void ldap_view_dn_mitem_cb (GtkMenuItem *menuitem, UiFormGrid *formgrid)
 }
 #endif
 
+static void
+proxy_changed_cb (GdauiDataProxy *dp, GdaDataProxy *proxy, UiFormGrid *formgrid)
+{
+	g_signal_emit (formgrid, ui_formgrid_signals [DATA_SET_CHANGED], 0);
+}
+
 /**
  * ui_formgrid_new
  * @model: a #GdaDataModel
@@ -689,6 +713,9 @@ ui_formgrid_new (GdaDataModel *model, gboolean scroll_form, GdauiDataProxyInfoFl
 		      "flags", formgrid->priv->flags | GDAUI_DATA_PROXY_INFO_CURRENT_ROW |
 		      GDAUI_DATA_PROXY_INFO_CHUNCK_CHANGE_BUTTONS, NULL);
 
+	g_signal_connect (formgrid->priv->raw_grid, "proxy-changed",
+			  G_CALLBACK (proxy_changed_cb), formgrid);
+
 	/* no more than 300 rows at a time */
 	if (model)
 		gda_data_proxy_set_sample_size (proxy, 300);
