@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 2010 - 2011 Vivien Malerba
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef __UI_FORMGRID__
@@ -50,11 +49,18 @@ struct _UiFormGrid
 struct _UiFormGridClass
 {
 	GtkVBoxClass       parent_class;
+	/* signals */
+	void             (*data_set_changed) (UiFormGrid *fg);
 };
 
-/* 
- * Generic widget's methods 
+/**
+ * SECTION:ui-formgrid
+ * @short_description: Widget embedding both a form and a grid to display a #GdaDataModel's contents
+ * @title: UiFormgrid
+ * @stability: Stable
+ * @see_also:
  */
+
 GType             ui_formgrid_get_type            (void);
 
 GtkWidget        *ui_formgrid_new                 (GdaDataModel *model, gboolean scroll_form,
