@@ -1,23 +1,19 @@
 /*
- * Copyright (C) 2011 The GNOME Foundation
+ * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -26,6 +22,8 @@
 #include "entry-properties.h"
 #include "marshal.h"
 #include <time.h>
+#include <libgda-ui/libgda-ui.h>
+#include "../text-search.h"
 
 struct _EntryPropertiesPrivate {
 	BrowserConnection *bcnc;
@@ -34,6 +32,8 @@ struct _EntryPropertiesPrivate {
 	GtkTextBuffer *text;
 	gboolean hovering_over_link;
 
+	GtkWidget *text_search;
+
 	/* coordinates of mouse */
 	gint bx;
 	gint by;
@@ -104,6 +104,7 @@ entry_properties_dispose (GObject *object)
 		if (eprop->priv->bcnc) {
 			g_object_unref (eprop->priv->bcnc);
 		}
+
 		g_free (eprop->priv);
 		eprop->priv = NULL;
 	}
@@ -140,6 +141,8 @@ static gboolean motion_notify_event (GtkWidget *text_view, GdkEventMotion *event
 static gboolean visibility_notify_event (GtkWidget *text_view, GdkEventVisibility *event, EntryProperties *eprop);
 static void populate_popup_cb (GtkWidget *text_view, GtkMenu *menu, EntryProperties *eprop);
 
+static void show_search_bar (EntryProperties *eprop);
+
 /**
  * entry_properties_new:
  *
@@ -219,10 +222,12 @@ data_save_cb (GtkWidget *mitem, EntryProperties *eprop)
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 					      NULL);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
+					     gdaui_get_default_path ());
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
 		char *filename;
 		GValue *binvalue;
-		GError *lerror;
+		GError *lerror = NULL;
 		const GdaBinary *bin = NULL;
 
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
@@ -236,6 +241,7 @@ data_save_cb (GtkWidget *mitem, EntryProperties *eprop)
 					    lerror && lerror->message ? lerror->message : _("No detail"));
 			g_clear_error (&lerror);
 		}
+		gdaui_set_default_path (gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dialog)));
 		g_free (filename);
 	}
 	gtk_widget_destroy (dialog);
@@ -453,7 +459,17 @@ key_press_event (GtkWidget *text_view, GdkEventKey *event, EntryProperties *epro
 						  gtk_text_buffer_get_insert (buffer));
 		follow_if_link (text_view, &iter, eprop);
 		break;
-		
+	case GDK_KEY_F:
+	case GDK_KEY_f:
+		if (event->state & GDK_CONTROL_MASK) {
+			show_search_bar (eprop);
+			return TRUE;
+		}
+		break;
+	case GDK_KEY_slash:
+		show_search_bar (eprop);
+		return TRUE;
+		break;
 	default:
 		break;
 	}
@@ -574,20 +590,34 @@ ad_1601_timestamp_to_string (const gchar *value, const gchar *attname)
 		return NULL;
 
 	GdaDataHandler *dh;
-	struct tm stm;
+	struct tm *stm;
 	GValue tvalue;
 	GdaTimestamp ts;
 	time_t nsec = (time_t) i64;
 	gchar *str;
-	 
-	localtime_r (&nsec, &stm);
+#ifdef HAVE_LOCALTIME_R
+	struct tm tmpstm;
+	stm = localtime_r (&nsec, &tmpstm);
+#elif HAVE_LOCALTIME_S
+	struct tm tmpstm;
+	if (localtime_s (&tmpstm, &nsec) == 0)
+		stm = &tmpstm;
+	else
+		stm = NULL;
+#else
+	stm = localtime (&nsec);
+#endif
+
+	if (!stm)
+		return NULL;
+
 	memset (&ts, 0, sizeof (GdaTimestamp));
-	ts.year = stm.tm_year + 1900;
-	ts.month = stm.tm_mon + 1;
-	ts.day = stm.tm_mday;
-	ts.hour = stm.tm_hour;
-	ts.minute = stm.tm_min;
-	ts.second = stm.tm_sec;
+	ts.year = stm->tm_year + 1900;
+	ts.month = stm->tm_mon + 1;
+	ts.day = stm->tm_mday;
+	ts.hour = stm->tm_hour;
+	ts.minute = stm->tm_min;
+	ts.second = stm->tm_sec;
 	ts.timezone = GDA_TIMEZONE_INVALID;
 	memset (&tvalue, 0, sizeof (GValue));
 	gda_value_set_timestamp (&tvalue, &ts);
@@ -891,6 +921,9 @@ info_fetch_cb (BrowserConnection *bcnc, gpointer out_result, EntryProperties *ep
 		browser_show_message (GTK_WINDOW (gtk_widget_get_toplevel ((GtkWidget*) eprop)),
 				      "%s", _("Could not get information about LDAP entry"));
 
+	if (eprop->priv->text_search && gtk_widget_get_visible (eprop->priv->text_search))
+		text_search_rerun (TEXT_SEARCH (eprop->priv->text_search));
+
 	g_object_unref (eprop);
 }
 
@@ -924,3 +957,19 @@ entry_properties_set_dn (EntryProperties *eprop, const gchar *dn)
 					      "%s", _("Could not get information about LDAP entry"));
 	}
 }
+
+static void
+show_search_bar (EntryProperties *eprop)
+{
+	if (! eprop->priv->text_search) {
+		eprop->priv->text_search = text_search_new (eprop->priv->view);
+		gtk_box_pack_start (GTK_BOX (eprop), eprop->priv->text_search, FALSE, FALSE, 0);
+		gtk_widget_show (eprop->priv->text_search);
+	}
+	else {
+		gtk_widget_show (eprop->priv->text_search);
+		text_search_rerun (TEXT_SEARCH (eprop->priv->text_search));
+	}
+
+	gtk_widget_grab_focus (eprop->priv->text_search);
+}
