@@ -228,15 +228,9 @@ source_drag_data_get_cb (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkDragC
 	case TARGET_KEY_VALUE: {
 		gchar *str;
 		str = ldap_entries_page_to_selection (ebrowser);
-#if GTK_CHECK_VERSION(2,18,0)
 		gtk_selection_data_set (selection_data,
 					gtk_selection_data_get_target (selection_data), 8, (guchar*) str,
 					strlen (str));
-#else
-		gtk_selection_data_set (selection_data,
-					(GdkAtom) selection_data->data, 8, (guchar*) str,
-					strlen (str));
-#endif
 		g_free (str);
 		break;
 	}
@@ -337,13 +331,13 @@ selection_changed_cb (GtkTreeSelection *sel, LdapEntriesPage *ebrowser)
 }
 
 static void
-open_dn_requested_cb (G_GNUC_UNUSED EntryProperties *eprop, const gchar *dn, LdapEntriesPage *ebrowser)
+open_dn_requested_cb (EntryProperties *eprop, const gchar *dn, LdapEntriesPage *ebrowser)
 {
 	ldap_entries_page_set_current_dn (ebrowser, dn);
 }
 
 static void
-open_class_requested_cb (G_GNUC_UNUSED EntryProperties *eprop, const gchar *classname, LdapEntriesPage *ebrowser)
+open_class_requested_cb (EntryProperties *eprop, const gchar *classname, LdapEntriesPage *ebrowser)
 {
 	BrowserPerspective *bpers;
 	bpers = browser_page_get_perspective (BROWSER_PAGE (ebrowser));
@@ -470,9 +464,9 @@ action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, LdapEntriesPage *ebrowser
 	BrowserFavorites *bfav;
         BrowserFavoritesAttributes fav;
         GError *error = NULL;
-	const gchar *cn;
+	const gchar *tmp, *cn;
 
-	hierarchy_view_get_current_dn (HIERARCHY_VIEW (ebrowser->priv->entries_view), &cn);
+	tmp = hierarchy_view_get_current_dn (HIERARCHY_VIEW (ebrowser->priv->entries_view), &cn);
         memset (&fav, 0, sizeof (BrowserFavoritesAttributes));
         fav.id = -1;
         fav.type = BROWSER_FAVORITES_LDAP_DN;
@@ -621,9 +615,11 @@ ldap_entries_page_page_get_actions_ui (G_GNUC_UNUSED BrowserPage *page)
 static GtkWidget *
 ldap_entries_page_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button)
 {
+	LdapEntriesPage *ebrowser;
 	const gchar *tab_name;
 	GdkPixbuf *entries_pixbuf;
 
+	ebrowser = LDAP_ENTRIES_PAGE (page);
 	entries_pixbuf = browser_get_pixbuf_icon (BROWSER_ICON_LDAP_ORGANIZATION);
 	tab_name = _("LDAP entries");
 	return browser_make_tab_label_with_pixbuf (tab_name,
