@@ -1,23 +1,20 @@
-/* 
- * Copyright (C) 2009 - 2011 The GNOME Foundation.
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -371,7 +368,7 @@ GdkPixbuf *
 browser_get_pixbuf_icon (BrowserIconType type)
 {
 	static GdkPixbuf **array = NULL;
-	static const gchar* names[] = {
+	static const gchar* names[] = { /* array indexed by BrowserIconType */
 		"gda-browser-bookmark.png",
 		"gda-browser-schema.png",
 		"gda-browser-table.png",
@@ -387,6 +384,14 @@ browser_get_pixbuf_icon (BrowserIconType type)
 		"gda-browser-grid.png",
 		"gda-browser-form.png",
 		"gda-browser-menu-ind.png",
+		"gda-browser-ldap-entry.png",
+		"gda-browser-ldap-group.png",
+		"gda-browser-ldap-organization.png",
+		"gda-browser-ldap-person.png",
+		"gda-browser-ldap-class-s.png",
+		"gda-browser-ldap-class-a.png",
+		"gda-browser-ldap-class-x.png",
+		"gda-browser-ldap-class-u.png",
 	};
 
 	if (!array)
@@ -406,6 +411,45 @@ browser_get_pixbuf_icon (BrowserIconType type)
 		return array [type];
 }
 
+#ifdef HAVE_LDAP
+/**
+ * browser_get_pixbuf_for_ldap_class:
+ */
+GdkPixbuf *
+browser_get_pixbuf_for_ldap_class (GdaLdapClassKind kind)
+{
+	switch (kind) {
+	case GDA_LDAP_CLASS_KIND_ABSTRACT:
+		return browser_get_pixbuf_icon (BROWSER_ICON_LDAP_CLASS_ABSTRACT);
+        case GDA_LDAP_CLASS_KIND_STRUTURAL:
+		return browser_get_pixbuf_icon (BROWSER_ICON_LDAP_CLASS_STRUCTURAL);
+        case GDA_LDAP_CLASS_KIND_AUXILIARY:
+		return browser_get_pixbuf_icon (BROWSER_ICON_LDAP_CLASS_AUXILIARY);
+        default:
+		return browser_get_pixbuf_icon (BROWSER_ICON_LDAP_CLASS_UNKNOWN);
+	}
+}
+
+/**
+ * browser_get_kind_for_ldap_class:
+ */
+const gchar *
+browser_get_kind_for_ldap_class (GdaLdapClassKind kind)
+{
+	switch (kind) {
+        case GDA_LDAP_CLASS_KIND_ABSTRACT:
+                return _("Abstract");
+        case GDA_LDAP_CLASS_KIND_STRUTURAL:
+                return _("Structural");
+        case GDA_LDAP_CLASS_KIND_AUXILIARY:
+                return _("Auxilliary");
+        default:
+                return _("Unknown");
+        }
+}
+#endif
+
+
 /**
  * browser_find_parent_widget
  *
